@@ -17,7 +17,7 @@
  *   along with this program; if not, write to the Free Software
  *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
-static char rcsid[] = "$Id: tvr_jpg.c,v 1.3 1997/02/21 16:57:03 pierre Exp $";
+static char rcsid[] = "$Id: tvr_jpg.c,v 1.5 1997/07/03 08:18:06 pierre Exp $";
 
 /*
  * Interface JPEG du mode Teletel vitesse rapide
@@ -167,7 +167,11 @@ typedef my_source_mgr * my_src_ptr;
  * before any data is actually read.
  */
 
+#if JPEG_LIB_VERSION >= 61
+METHODDEF(void)
+#else
 METHODDEF void
+#endif
 init_source (j_decompress_ptr cinfo)
 {
   my_src_ptr src = (my_src_ptr) cinfo->src;
@@ -183,7 +187,11 @@ init_source (j_decompress_ptr cinfo)
 /*
  * Fill the input buffer --- called whenever buffer is emptied.
  */
+#if JPEG_LIB_VERSION >= 61
+METHODDEF(boolean)
+#else
 METHODDEF boolean
+#endif
 fill_input_buffer (j_decompress_ptr cinfo)
 {
   my_src_ptr src = (my_src_ptr) cinfo->src;
@@ -224,8 +232,11 @@ fill_input_buffer (j_decompress_ptr cinfo)
  * Skip data --- used to skip over a potentially large amount of
  * uninteresting data (such as an APPn marker).
  */
-
+#if JPEG_LIB_VERSION >= 61
+METHODDEF(void)
+#else
 METHODDEF void
+#endif
 skip_input_data (j_decompress_ptr cinfo, long num_bytes)
 {
   my_src_ptr src = (my_src_ptr) cinfo->src;
@@ -264,8 +275,11 @@ skip_input_data (j_decompress_ptr cinfo, long num_bytes)
  * application must deal with any cleanup that should happen even
  * for error exit.
  */
-
+#if JPEG_LIB_VERSION >= 61
+METHODDEF(void)
+#else
 METHODDEF void
+#endif
 term_source (j_decompress_ptr cinfo)
 {
   /* no work necessary here */
@@ -277,8 +291,11 @@ term_source (j_decompress_ptr cinfo)
  * The caller must have already opened the stream, and is responsible
  * for closing it after finishing decompression.
  */
-
+#if JPEG_LIB_VERSION >= 61
+LOCAL(void)
+#else
 LOCAL void
+#endif
 jpeg_fd_src (j_decompress_ptr cinfo, int infile, int l)
 {
   my_src_ptr src;
@@ -315,7 +332,11 @@ jpeg_fd_src (j_decompress_ptr cinfo, int infile, int l)
 /*
  * Write some pixel data
  */
+#if JPEG_LIB_VERSION >= 61
+METHODDEF(void)
+#else
 METHODDEF void
+#endif
 put_pixel_rows (j_decompress_ptr cinfo, djpeg_dest_ptr dinfo,
 		  JDIMENSION rows_supplied)
 {
@@ -438,8 +459,11 @@ put_pixel_rows (j_decompress_ptr cinfo, djpeg_dest_ptr dinfo,
 /*
  * Startup: write the file header.
  */
-
+#if JPEG_LIB_VERSION >= 61
+METHODDEF(void)
+#else
 METHODDEF void
+#endif
 start_output_x11 (j_decompress_ptr cinfo, djpeg_dest_ptr dinfo)
 {
   x11_dest_ptr dest = (x11_dest_ptr) dinfo;
@@ -492,8 +516,11 @@ start_output_x11 (j_decompress_ptr cinfo, djpeg_dest_ptr dinfo)
 /*
  * Finish up at the end of the file.
  */
-
+#if JPEG_LIB_VERSION >= 61
+METHODDEF(void)
+#else
 METHODDEF void
+#endif
 finish_output_x11 (j_decompress_ptr cinfo, djpeg_dest_ptr dinfo)
 {
     x11_dest_ptr dest = (x11_dest_ptr) dinfo;
@@ -506,8 +533,11 @@ finish_output_x11 (j_decompress_ptr cinfo, djpeg_dest_ptr dinfo)
 /*
  * The module selection routine for X format output.
  */
-
+#if JPEG_LIB_VERSION >= 61
+GLOBAL(djpeg_dest_ptr)
+#else
 GLOBAL djpeg_dest_ptr
+#endif
 jinit_write_x11 (j_decompress_ptr cinfo, VideotexWidget w)
 {
   x11_dest_ptr dest;
@@ -557,7 +587,7 @@ jinit_write_x11 (j_decompress_ptr cinfo, VideotexWidget w)
   dest->flag_bs = pv->flag_bs;
   dest->win_sauve = pv->ecran_sauve;
   dest->nplanes = DisplayPlanes (dest->display, dest->screen);
-  dest->cmap = DefaultColormap (dest->display, dest->screen);
+  dest->cmap = w->core.colormap;
   dest->flag_double = !pv->petite_fonte;
   dest->modulo = 8;
   dest->x_photo = pv->rectangle_photo.x;
@@ -622,8 +652,11 @@ jinit_write_x11 (j_decompress_ptr cinfo, VideotexWidget w)
  * We want to print out the marker as text, if possible.
  * Note this code relies on a non-suspending data source.
  */
-
+#if JPEG_LIB_VERSION >= 61
+LOCAL(unsigned int)
+#else
 LOCAL unsigned int
+#endif
 jpeg_getc (j_decompress_ptr cinfo)
 /* Read next byte */
 {
@@ -637,7 +670,11 @@ jpeg_getc (j_decompress_ptr cinfo)
   return GETJOCTET(*datasrc->next_input_byte++);
 }
 
+#if JPEG_LIB_VERSION >= 61
+METHODDEF(boolean)
+#else
 METHODDEF boolean
+#endif
 COM_handler (j_decompress_ptr cinfo)
 {
   boolean traceit = (cinfo->err->trace_level >= 1);
@@ -755,7 +792,7 @@ void libere_couleurs_tvr (w)
 VideotexWidget w;
 {
     if (last_color) {
-	XFreeColors (XtDisplay(w), DefaultColormap (XtDisplay(w), DefaultScreen(XtDisplay(w))), pixels, last_color, 0);
+	XFreeColors (XtDisplay(w), w->core.colormap, pixels, last_color, 0);
 	last_color = 0;
     }
 }
