@@ -17,7 +17,7 @@
  *   along with this program; if not, write to the Free Software
  *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
-static char rcsid[] = "$Id: xvdt.c,v 1.4 1997/07/03 08:18:32 pierre Exp $";
+static char rcsid[] = "$Id: xvdt.c,v 1.5 1998/10/02 14:51:37 pierre Exp $";
 
 /*
  * Test du widget Videotex
@@ -31,25 +31,61 @@ static char rcsid[] = "$Id: xvdt.c,v 1.4 1997/07/03 08:18:32 pierre Exp $";
 
 #include "Videotex.h"
 
-Widget toplevel, form, vdts;
-XtAppContext app_context;
-Colormap new_cmap;
+extern char *basename ();
+
+static Widget toplevel, form, vdts;
+static XtAppContext app_context;
+static Colormap new_cmap;
+static int fd;
+static XtInputId input_id;
+static char *xteld_serveur, *xteld_service;
 
 static void Fin (w, client_data, pevent)
 Widget w;
 caddr_t client_data;
 XButtonEvent *pevent;
 {
-    exit (0);
+  if (xteld_serveur) {
+    XtRemoveInput (input_id);
+    close (fd);
+  }
+  exit (0);
+
 }
 
+void read_the_server (client_data, fid, id)
+XtPointer client_data;	/* non utilise */
+int *fid;
+XtInputId *id;
+{
+    unsigned char c;
+
+    if (read (*fid, &c, 1) > 0)
+      videotexDecode (vdts, c);
+}
+
+static void OpenConnection (w, client_data, pevent)
+Widget w;
+caddr_t client_data;
+XButtonEvent *pevent;
+{
+    char c;
+
+    if ((fd = c_clientbyname (xteld_serveur, xteld_service)) < 0) {
+      fprintf (stderr, "OpenConnection: Erreur de connexion au serveur %s, service%s.\n", xteld_serveur, xteld_service);
+      exit (1);
+    }
+
+    XtVaSetValues (vdts, XtNfdConnexion, fd, NULL);
+    input_id = XtAppAddInput (app_context, fd, (XtPointer)XtInputReadMask, (XtInputCallbackProc)read_the_server, NULL);
+}    
+
 static void Decode (w, client_data, pevent)
 Widget w;
 caddr_t client_data;
 XButtonEvent *pevent;
 {
     char c;
-    int fd;
 
     fd = open (client_data, O_RDONLY);
     
@@ -66,40 +102,71 @@ XButtonEvent *pevent;
     }
 }
 
+static void Usage (char *s)
+{
+  fprintf (stderr, "%s: [-p] [-s serveur] [-S service] [fichier]\n", s);
+  exit (1);
+}
+
 main (ac, av)
 int ac;
 char **av;
 {
-    char *filename;
+    char *filename, *progname, *cp;
     Boolean private_cmap = False;
     int i;
 
+    progname = basename(av[0]);
+
     toplevel = XtAppInitialize(&app_context, "XVdt", NULL, 0, &ac, av, NULL, NULL, 0); 
 
-    i = 1;
-    while (i < ac) {
-	if (strncmp (av[i], "-p", 2) == 0)
+    if (ac < 2)
+      Usage (progname);
+
+    /* Lecture de la ligne de commande */
+    while (--ac) {
+	if ((cp = *++av) == NULL)
+	  break;
+	if (*cp == '-' && *++cp) {
+	  switch(*cp) {
+
+	  case 'p' :
+	    ++av;
 	    private_cmap = True;
-	else if (av[i][0] != '-') {
-	    filename = av[i];
+	    break;
+
+	  case 's' :
+	    xteld_serveur = *++av; break;
+
+	  case 'S':
+	    xteld_service = *++av; break;
+
+	  default:
+	    Usage (progname);
+	  }
 	}
 	else {
-	    fprintf (stderr, "Usage: xvdt fichier_videotex\n");
-	    exit (1);
+	    break;
 	}
-
-	i++;
     }
     
+    filename = cp;
+    if (xteld_serveur && !xteld_service)
+      xteld_service = "xtel";
+
     if (private_cmap) {
-	new_cmap = XCopyColormapAndFree ( XtDisplay(toplevel), DefaultColormapOfScreen ( XtScreen( toplevel)) );
+	new_cmap = XCopyColormapAndFree (XtDisplay(toplevel), DefaultColormapOfScreen ( XtScreen( toplevel)) );
 	XtVaSetValues (toplevel, XtNcolormap, new_cmap, NULL);
     }
 
     form = XtCreateManagedWidget ("form", formWidgetClass, toplevel, NULL, 0);
-    vdts = XtVaCreateManagedWidget ("vdts", videotexWidgetClass, form, XtNenqROM, "Cv1", NULL);
+    vdts = XtVaCreateManagedWidget ("vdts", videotexWidgetClass, form, XtNenqROM, "Cv1", XtNconnecte, True, NULL);
+
+    if (xteld_serveur)
+      XtAddEventHandler (vdts, ExposureMask, False, OpenConnection, (caddr_t)NULL);
+    else
+      XtAddEventHandler (vdts, ExposureMask, False, Decode, (caddr_t)filename);
 
-    XtAddEventHandler (vdts, ExposureMask, False, Decode, (caddr_t)filename);
     XtAddEventHandler (vdts, ButtonPressMask, False, Fin, NULL);
 
     XtRealizeWidget(toplevel);
