@@ -15,7 +15,7 @@
  *   along with this program; if not, write to the Free Software
  *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
-static char rcsid[] = "$Id: XpmButton.c,v 1.4 1997/02/21 17:12:20 pierre Exp $";
+static char rcsid[] = "$Id: XpmButton.c,v 1.6 1997/07/08 10:13:59 pierre Exp $";
 
 /*
  * XpmButton, a simple push/toggle button widget with a nice 
@@ -178,12 +178,16 @@ Cardinal *num_args;		/* unused */
   int rab, width, height;
   Window root;
   XGCValues	values;
+  XpmAttributes xpma;
+
+  xpma.colormap = new->core.colormap;
+  xpma.valuemask = XpmColormap;
 
   /* If no Pixmap defined, use the default ;-) */
   if (xbw->xpmbutton.pixmap1 == None) {
       fprintf (stderr, "xpmButtonWidget: Warning, no Pixmap defined, using default.\n");
-      XpmCreatePixmapFromData (XtDisplay(new), RootWindowOfScreen(XtScreen(new)), default_xpm, &xbw->xpmbutton.pixmap1, NULL, NULL);
-      XpmCreatePixmapFromData (XtDisplay(new), RootWindowOfScreen(XtScreen(new)), default_on_xpm, &xbw->xpmbutton.pixmap2, NULL, NULL);
+      XpmCreatePixmapFromData (XtDisplay(new), RootWindowOfScreen(XtScreen(new)), default_xpm, &xbw->xpmbutton.pixmap1, NULL, &xpma);
+      XpmCreatePixmapFromData (XtDisplay(new), RootWindowOfScreen(XtScreen(new)), default_on_xpm, &xbw->xpmbutton.pixmap2, NULL, &xpma);
 
   }
 
@@ -282,12 +286,12 @@ Pixmap pixmap, shape;
 	    poly2[5].x = st; poly2[5].y = hh+st;
 
 	    if (xbw->xpmbutton.set) {
-		XFillPolygon (XtDisplay(w), XtWindow(w), xbw->xpmbutton.color2_GC, poly1, 6, Convex, CoordModeOrigin);
-		XFillPolygon (XtDisplay(w), XtWindow(w), xbw->xpmbutton.color1_GC, poly2, 6, Convex, CoordModeOrigin);
+		XFillPolygon (XtDisplay(w), XtWindow(w), xbw->xpmbutton.color2_GC, poly1, 6, Nonconvex, CoordModeOrigin);
+		XFillPolygon (XtDisplay(w), XtWindow(w), xbw->xpmbutton.color1_GC, poly2, 6, Nonconvex, CoordModeOrigin);
 	    }
 	    else {
-		XFillPolygon (XtDisplay(w), XtWindow(w), xbw->xpmbutton.color1_GC, poly1, 6, Convex, CoordModeOrigin);
-		XFillPolygon (XtDisplay(w), XtWindow(w), xbw->xpmbutton.color2_GC, poly2, 6, Convex, CoordModeOrigin);
+		XFillPolygon (XtDisplay(w), XtWindow(w), xbw->xpmbutton.color1_GC, poly1, 6, Nonconvex, CoordModeOrigin);
+		XFillPolygon (XtDisplay(w), XtWindow(w), xbw->xpmbutton.color2_GC, poly2, 6, Nonconvex, CoordModeOrigin);
 	    }
 	}
     }
