@@ -17,7 +17,7 @@
  *   along with this program; if not, write to the Free Software
  *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
-static char rcsid[] = "$Id: bouton.c,v 1.8 1998/10/02 14:56:19 pierre Exp $";
+static char rcsid[] = "$Id: bouton.c,v 1.10 1999/09/14 11:48:41 pierre Exp $";
 
 /*
  * fonctions associees aux boutons
@@ -170,7 +170,7 @@ int flag;
     /* Valide la sensibilite du clavier Minitel */
     for (i = 4; i < 14 ; i++) {
 	if ((w = XtNameToWidget (menu_clavier, touches[i].nom)) == NULL) {
-	    printf ("erreur XtNameToWidget %s\n", touches[i].nom);
+	    fprintf (stderr, "erreur XtNameToWidget %s\n", touches[i].nom);
 	    return;
 	}
 
@@ -185,7 +185,7 @@ int flag;
 	    if (strcmp (touches[i].nom, "blanc") != 0) {
 		sprintf (buf, "btn_%s", touches[i].nom);
 		if ((w = XtNameToWidget (boite_bas, buf)) == NULL) {
-		    printf ("erreur XtNameToWidget %s\n", buf);
+		    fprintf (stderr, "erreur XtNameToWidget %s\n", buf);
 		    return;
 		}
 
@@ -200,7 +200,14 @@ int flag;
 
     if (rsc_xtel.boutonRaccrocher) {
 	if ((w = XtNameToWidget (menu_clavier, "raccrocher")) == NULL) {
-	    printf ("erreur XtNameToWidget raccrocher\n");
+	    fprintf (stderr, "erreur XtNameToWidget raccrocher\n");
+	    return;
+	}
+	
+	XtSetSensitive (w, flag);
+
+	if ((w = XtNameToWidget (menu_fichier, "raccrocher")) == NULL) {
+	    fprintf (stderr, "erreur XtNameToWidget raccrocher\n");
 	    return;
 	}
 	
@@ -213,7 +220,6 @@ int flag;
 }
 
 /* Fixe la partie mode d'emulation */
-
 void mise_a_jour_mode_emulation (flag_invalide)
 char flag_invalide;
 {
@@ -221,8 +227,19 @@ char flag_invalide;
     Widget w;
 
     for (i = 0 ; i != 3; i++) {
+	if ((w = XtNameToWidget (menu_terminal, touches[i].nom)) == NULL) {
+	    fprintf (stderr, "erreur XtNameToWidget %s\n", touches[i].nom);
+	    return;
+	}
+
+	if (i == mode_emulation || flag_invalide)
+	    XtSetSensitive (w, False);
+	else
+	    XtSetSensitive (w, True);
+
+	/* Idem pour popup-menu */
 	if ((w = XtNameToWidget (menu_clavier, touches[i].nom)) == NULL) {
-	    printf ("erreur XtNameToWidget %s\n", touches[i].nom);
+	    fprintf (stderr, "erreur XtNameToWidget %s\n", touches[i].nom);
 	    return;
 	}
 
