@@ -17,7 +17,7 @@
  *   along with this program; if not, write to the Free Software
  *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
-static char rcsid[] = "$Id: config.c,v 1.13 1998/10/02 14:58:05 pierre Exp $";
+static char rcsid[] = "$Id: config.c,v 1.14 1998/10/16 08:49:01 pierre Exp $";
 
 /*
  * fonctions de lecture de la configuration
@@ -103,9 +103,14 @@ static int get_separator (char *s, char *sep)
   register char *p = s;
 
 #ifdef DEBUG_XTELD
-    log_debug ("get_separator: *p = %c %x", *p, *p);
+  log_debug ("get_separator: *p = %c %x", *p, *p);
 #endif
 
+  /* Cas particulier des lignes @pipe/@tcp de xtel.services */
+  if (*p == '@') {
+    *sep = ',';
+    return 0;
+  }
   
   while (*p && ((*p >= 'a' && *p <= 'z') || (*p >= 'A' && *p <= 'Z') || (*p >= '0' && *p <= '9') || *p == '_' || *p == '-')) {
 #ifdef DEBUG_XTELD
