@@ -17,7 +17,7 @@
  *   along with this program; if not, write to the Free Software
  *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
-static char rcsid[] = "$Id: copyright.c,v 1.8 1998/10/02 14:59:50 pierre Exp $";
+static char rcsid[] = "$Id: copyright.c,v 1.9 2001/02/10 23:56:45 pierre Exp $";
 
 #include "xtel.h"
 #include "patchlevel.h"
@@ -31,11 +31,7 @@ static char rcsid[] = "$Id: copyright.c,v 1.8 1998/10/02 14:59:50 pierre Exp $";
 #endif
 #define W_COPYRIGHT	320
 
-#ifdef NO_NETWORK
-static char *sockets = "locales";
-#else
 static char *sockets = "Internet";
-#endif /* NO_NETWORK */
 static Display *display;
 static GC gc_copyright;
 static int screen;
