@@ -17,7 +17,7 @@
  *   along with this program; if not, write to the Free Software
  *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
-#ident "$Id: demon.h,v 1.10 1998/10/16 08:49:21 pierre Exp $"
+#ident "$Id: demon.h,v 1.11 2001/02/10 23:57:32 pierre Exp $"
 
 #ifndef _demon_h
 #define _demon_h
@@ -131,4 +131,11 @@ struct definition_ligne {
 #define XTEL_UNIX_PATH		"/tmp/.xtel"	/* Nom des sockets unix utilisees */
 #endif /* NO_NETWORK */
 
-#endif
+/* Fichier d'tat I-Minitel */
+#define IMINITEL_FILE            "/tmp/.iminitel"
+#define IMINITEL_TIMEOUT         45
+
+/* Base /proc */
+#define PROC_BASE                "/proc"
+
+#endif /* _demon_h */
