@@ -26,9 +26,7 @@
  *      D'apres Ronan KERYELL (Ecole Normale Superieure, Paris)
  *               keryell@ens.fr
  */
-static char rcsid[] = "$Id: inet.c,v 1.3 1996/10/04 17:04:11 pierre Exp $";
-
-#ifndef NO_NETWORK
+static char rcsid[] = "$Id: inet.c,v 1.5 2001/02/13 09:36:43 pierre Exp $";
 
 #include <sys/types.h>
 #define _TYPE
@@ -110,15 +108,6 @@ c_clientbyport (host, port)
 char *host;
 int port;
 {
-  struct servent *sv;  
-
-  /* Description du service recherche (essentiellement, le numero de port) */
-  if (!(sv = getservbyport (htons(port), "tcp"))) {
-    perror ("getservbyport");
-    return (-1);
-  }
-
-  return (c_socket (host, sv->s_port));
+  return (c_socket (host, htons(port)));
 }
 
-#endif /* NO_NETWORK */
