@@ -17,7 +17,7 @@
  *   along with this program; if not, write to the Free Software
  *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
-static char rcsid[] = "$Id: lecteur.c,v 1.3 1996/09/22 21:10:26 pierre Exp $";
+static char rcsid[] = "$Id: lecteur.c,v 1.4 2001/02/11 00:01:00 pierre Exp $";
 
 /*
  * Fonctions du lecteur
@@ -28,8 +28,6 @@ static char rcsid[] = "$Id: lecteur.c,v 1.3 1996/09/22 21:10:26 pierre Exp $";
 #include <signal.h>
 
 static XtInputId input_id_lecteur;
-static char *passage_videotex = "\033[?{";
-static char indice_reception;
 static int fd_fichier_lu;
 static Boolean flag_arret_a_decoder, flag_sep;
 
@@ -94,21 +92,18 @@ XtInputId *id;
 	}
 
 	if (mode_emulation != MODE_VIDEOTEX) {
-	    if (*(passage_videotex+indice_reception) == c) {
-		if (indice_reception == 3) {
-		    mode_emulation = MODE_VIDEOTEX;
-		    kill (pid_teleinfo, SIGKILL);
-		    close (fd_teleinfo);
 
-		}
-		else 
-		    indice_reception = (indice_reception == 3 ? 0 : indice_reception++);
-	    }   
-	    
-	    if (mode_emulation == MODE_TELEINFO_FR)
-		c = conversion_teleinfo_fr (c);
+	    int retour_videotex = test_retour_videotex ( c,3) ;
 
-	    write (fd_teleinfo, &c, 1);
+	    if ( ( retour_videotex == 1 ) || ( retour_videotex == 2 ) ) {
+	      mode_emulation = MODE_VIDEOTEX;
+	      kill (pid_teleinfo, SIGKILL);
+	      close (fd_teleinfo);
+	    } else {
+	      if (mode_emulation == MODE_TELEINFO_FR)
+		c = conversion_teleinfo_fr (c,3);
+	      write (fd_teleinfo, &c, 1);
+	    }
 	}
 	else {
 	    /* decodage */
@@ -236,6 +231,7 @@ XtPointer client_data, call_data;
     position_courante_fichier = 0L;
     numero_page_courante = 1;
     numero_caractere_courant = 0;
+    clear_reception () ;
     affiche_compteur_lecteur_caractere ();
     affiche_compteur_lecteur_page ();
 }
