@@ -17,7 +17,7 @@
  *   along with this program; if not, write to the Free Software
  *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
-static char rcsid[] = "$Id: ligne.c,v 1.10 1998/10/02 15:05:02 pierre Exp $";
+static char rcsid[] = "$Id: ligne.c,v 1.11 2001/02/11 00:01:34 pierre Exp $";
 
 /*
  * fonctions de traitement de la ligne MODEM
@@ -31,11 +31,6 @@ static char rcsid[] = "$Id: ligne.c,v 1.10 1998/10/02 15:05:02 pierre Exp $";
 
 #include "Timer.h"
 
-#ifdef NO_NETWORK
-#include <sys/socket.h>
-#include <sys/un.h>
-#endif /* NO_NETWORK */
-
 static char erreur, compte_erreur, message_erreur[80];
 static char buf_temps_maxi[4];
 static int temps_maxi;
@@ -170,10 +165,20 @@ XtInputId *id;
 	    efface_telephone ();
 
 	    /* decodage */
-	    if (mode_emulation != MODE_VIDEOTEX)
-	      write (fd_teleinfo, &c, 1);
-	    else
+	    if (mode_emulation != MODE_VIDEOTEX) {
+	      int retour_videotex = test_retour_videotex ( c,1) ;
+
+	      if ( ( retour_videotex == 1 ) || ( retour_videotex == 2 ) ) {
+		    selection_mode_emulation (ecran_minitel, "V", NULL);
+		    return;
+	      } else {
+		if (mode_emulation == MODE_TELEINFO_FR)
+		  c = conversion_teleinfo_fr (c,1);
+		write (fd_teleinfo, &c, 1);
+	      }
+	    } else {
 	      videotexDecode (ecran_minitel, c);
+	    }
 	}
     } 
     /* Non connecte */
@@ -264,22 +269,10 @@ char *service;
     lecteur_valide (False);
 
     /* Ouvre la socket serveur */
-#ifdef NO_NETWORK
-    if ((socket_xteld = socket (AF_UNIX, SOCK_STREAM, 0))  < 0) {
-	perror ("socket");
-	exit (1);
-    }
-
-    if (connect (socket_xteld, (struct sockaddr *)&unaddr, sizeof(unaddr)) < 0) {
-	perror ("connect");
-	exit (1);
-    }
-#else
     if ((socket_xteld = c_clientbyname(rsc_xtel.serveur, rsc_xtel.nomService)) < 0) {
       fprintf (stderr, "Erreur de connexion au serveur XTEL...\n");
       return;
     }
-#endif /* NO_NETWORK */
 
     /* Transmet le nom d'utilisateur */
     if ((pw = getpwuid(getuid())) == NULL) {
