@@ -1,11 +1,10 @@
 #!/bin/sh
-# $Id: make_xtel_lignes.sh,v 1.3 1999/09/17 12:15:41 pierre Exp $
+# $Id: make_xtel_lignes.sh,v 1.5 2001/02/11 19:27:59 pierre Exp $
 
 # Dtection des modems
 
 XTEL_LIGNES="/usr/X11R6/lib/X11/xtel/xtel.lignes"
 MDMDETECT="/usr/X11R6/bin/mdmdetect"
-MDM_URL="http://www.alienor.fr/~pierre/xtel/modem.list"
 
 KERNELV=`uname -r | tr -d "." | cut -c1,2`
 
@@ -22,29 +21,10 @@ tput rev
 echo "Dtection des modems et gnration du xtel.lignes (kernel `uname -r`)"
 tput rmso
 
-# Liste locale ou Internet
-
-cat <<EOF
-
-Une liste des modems reconnus est disponible sur le disque mais vous pouvez
-galement choisir d'utiliser la version mise  jour sur Internet. Dans ce cas,
-vous devez imprativement tre connect au moment de la dtection des modems.
-
-EOF
-
-echo -n "Voulez-vous utiliser la liste sur Internet [n] ? "
-read c < /dev/tty
-
-if [ "$c" = "O" -o "$c" = "o" ]; then
-	MDM_LIST="-l $MDM_URL/modem.list"
-fi
-
-M=`$MDMDETECT -q $MDM_LIST`
-
+M=`$MDMDETECT -q`
 if [ "$M" = "" ]; then
-    echo "Lecture de la liste impossible, retour  la liste locale..."
-    sleep 2
-    unset MDM_LIST
+    echo "Liste des modems non disponible !"
+    exit 1
 fi
 
 if [ -r $XTEL_LIGNES ]; then
