@@ -18,7 +18,7 @@
  *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *		 
  */
-static char rcsid[] = "$Id: mdmdetect.c,v 1.2 1999/08/31 14:09:59 pierre Exp $";
+static char rcsid[] = "$Id: mdmdetect.c,v 1.3 2001/02/11 00:02:58 pierre Exp $";
 
 /* Detection du modem pour generation du xtel.lignes */
 
@@ -222,6 +222,9 @@ char **av;
   char *cp, *str1, *str2;
   register int i;
   int found = 0;
+#ifdef DEBUG_XTELD
+  debug = 1;
+#endif
 
   progname = xtel_basename(av[0]);
 
