@@ -18,7 +18,7 @@
  *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *		 
  */
-static char rcsid[] = "$Id: modem.c,v 1.1 1998/10/16 08:54:12 pierre Exp $";
+static char rcsid[] = "$Id: modem.c,v 1.2 2001/02/13 09:39:23 pierre Exp $";
 
 /* Init du modem */
 
@@ -71,7 +71,7 @@ void init_debug (char *s)
 {
   strcpy (prefix, s);
 #ifdef USE_SYSLOG
-    openlog(s, LOG_PID | LOG_CONS, LOG_DAEMON);
+    openlog(s, LOG_PID | LOG_CONS, LOG_INFO);
 #else
     if ((fp_console = fopen ("/dev/console", "w")) == NULL) {
         perror ("/dev/console");
@@ -82,7 +82,7 @@ void init_debug (char *s)
 
 void close_debug ()
 {
-#ifndef SYSLOG
+#ifndef USE_SYSLOG
   fclose (fp_console);
 #endif
 }
@@ -96,13 +96,13 @@ int  p1, p2, p3, p4, p5, p6, p7;
     char msg[256];
 
     sprintf (msg, fmt, p1, p2, p3, p4, p5, p6, p7);
-    syslog(LOG_DEBUG, msg);
+    syslog (LOG_INFO, msg);
 }
 
 void log_err (s)
 char *s;
 {
-    syslog(LOG_ERR, s);
+    syslog (LOG_ERR, s);
 }
 #else
 void log_debug (fmt, p1, p2, p3, p4, p5, p6, p7)
