@@ -17,11 +17,12 @@
  *   along with this program; if not, write to the Free Software
  *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
-static char rcsid[] = "$Id: procedure.c,v 1.4 1996/10/28 13:37:35 pierre Exp $";
+static char rcsid[] = "$Id: procedure.c,v 1.5 1998/10/02 15:06:18 pierre Exp $";
 
 #include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
+#include <errno.h>
 
 #include "xtel.h"
 
@@ -38,6 +39,8 @@ static struct keyword keywords[] = {
     { "write", 'W', P_WRI },
     { "hangup", 'H', P_HUP },
     { "exit", 'X', P_EXI },
+    { "asciidump", 'd', P_ADMP },
+    { "ppmdump", 'D', P_PDMP },
     { NULL, 0, 0 }
 };
 
@@ -122,6 +125,8 @@ char *file;
 	break;
 
 	case P_WRI :
+	case P_ADMP :
+	case P_PDMP :
 
 	  (pd->p).filename = strdup (s);
 	break;
@@ -159,9 +164,10 @@ char *name;
     if (!name)
 	return -1;
 
-    for (i = 0 ; i <= iproc ; i++)
-	if (!strcmp (procedures[i].nom, name))
-	    return i;
+    for (i = 0 ; i <= iproc ; i++) {
+      if (!strcmp (procedures[i].nom, name))
+	return i;
+    }
 
     return -1;
 }
@@ -225,6 +231,35 @@ int fd;
 		Sauve ();
 		break;
 
+	    case P_ADMP :
+
+	      { 
+		FILE *fp = fopen ((current_pd->p).filename, "w");
+
+		if (fp) {
+		  videotexConversionAscii (ecran_minitel, fp);
+		  fclose (fp);
+		}
+		else
+		  fprintf (stderr, "run_procedure: %s: %s\n", (current_pd->p).filename, sys_errlist[errno]);
+	      }
+	    break;
+
+	    case P_PDMP :
+
+	      { 
+		FILE *fp = fopen ((current_pd->p).filename, "w");
+
+		if (fp) {
+		  videotexDumpScreen (ecran_minitel, fp);
+		  fclose (fp);
+		}
+		else
+		  fprintf (stderr, "run_procedure: %s: %s\n", (current_pd->p).filename, sys_errlist[errno]);
+	      }
+
+	    break;
+
 	      case P_HUP :
 
 		write (fd, CHAINE_COMMANDE_FIN, 1);
@@ -291,6 +326,3 @@ void display_procedures ()
     }
   }
 }
-
-
-
