@@ -17,7 +17,7 @@
  *   along with this program; if not, write to the Free Software
  *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
-static char rcsid[] = "$Id: teleinfo.c,v 1.5 1996/09/25 10:15:47 pierre Exp $";
+static char rcsid[] = "$Id: teleinfo.c,v 1.6 2001/02/11 00:03:58 pierre Exp $";
 
 /*
  * Traitement du mode Tele-informatique
@@ -52,8 +52,8 @@ static char rcsid[] = "$Id: teleinfo.c,v 1.5 1996/09/25 10:15:47 pierre Exp $";
 static char pty_m[20], pty_s[20];
 static char buf[10];
 static int fd_m;
-static char *passage_videotex = "\033[?{";
-static char indice_reception;
+
+static int car_precedent_est_escape[4] = {0,0,0,0} ;
 
 /* En cas de malheur (sans Gabin cette fois...) */
 static void teleinfo_fatal (s1, s2, s3)
@@ -231,11 +231,16 @@ static void sigchld ()
  * amelioration pour ceux que ca interesse (y en a-t-il ???) ==> faire
  * une fonte speciale...
  */
-char conversion_teleinfo_fr (car)
+char conversion_teleinfo_fr (car,m)
 char car;
+int  m ; 
 {
     register char c;
     
+    if ( car_precedent_est_escape[m] ) {
+      car_precedent_est_escape[m]=0 ;
+      return car ;
+    }
     switch (car) {
 	
       case '{' :
@@ -245,7 +250,7 @@ char car;
 	  
 	case '}' :
 	    
-	    c = 0xe8; /* etc... */
+	  c = 0xe8; /* etc... */
 	  break;
 	  
 	case '@' :
@@ -272,7 +277,15 @@ char car;
 	    
 	    c = 0xa3;
 	  break;
+
+      case 0x0e :
+          c = 0xef ;
+	break ;
 	  
+      case 0x1b :
+          c = car ;
+          car_precedent_est_escape[m] = 1 ;
+	break ;
 	  default :
 	      c = car;
       }
@@ -295,19 +308,9 @@ XtInputId *id;
     XtVaGetValues (ecran_minitel, XtNconnecte, &flag_connexion, NULL);
     
     if (read (*fid, &c, 1) == 1)  {
-	/* Test de reception de la chaine de retour en Videotex (ESC [?{) */
-	if (*(passage_videotex+indice_reception) == c) {
-	    if (indice_reception == 3) {
-		selection_mode_emulation (ecran_minitel, "V", NULL);
-		return;
-	    }
-	    else 
-		indice_reception = (indice_reception == 3 ? 0 : indice_reception++);
-	}   
-
-	if (mode_emulation == MODE_TELEINFO_FR)
-	    c = conversion_teleinfo_fr (c);
-
+        if (mode_emulation == MODE_TELEINFO_FR)
+	     c = conversion_teleinfo_fr (c,2);
+      
 	if (flag_connexion)
 	    write (socket_xteld, &c, 1);
 	else
@@ -341,10 +344,11 @@ XtPointer call_data;
 	mode_emulation = MODE_VIDEOTEX;
 	zigouille_xterm_teleinfo ();
 	XtVaSetValues (ecran_minitel, XtNmodeVideotex, True, NULL);
+	XtVaSetValues (ecran_minitel, XtNfdConnexion, socket_xteld, NULL);
     }
     else {
 	signal (SIGCHLD, sigchld);
-	indice_reception = 0;
+	clear_reception() ;
 	XtVaSetValues (ecran_minitel, XtNmodeVideotex, False, NULL);
 	if (mode[0] == 'A') {
 	    if (mode_emulation == MODE_TELEINFO_FR) {
@@ -374,3 +378,63 @@ XtPointer call_data;
 
 
 
+/*--------------------------------------------------------------------------*/
+/* deux petites procedures                                                  */
+/*   - detection de la sequence pour arrete les modes 80 colonnes           */
+/*--------------------------------------------------------------------------*/
+
+static char *passage_videotex = "\033[?{";
+static int indice_reception[4]= {0,0,0,0};
+
+/* voir 3617 sirene , attention 2frs la minute */
+static char *fin_mode_teleinfo_fr = "\033:2~";
+static int indice_reception_fin_fr[4]= {0,0,0,0};
+
+/* |----------------------------------------------------------------------| */
+/* | on met les compteurs a zero                                          | */
+/* |----------------------------------------------------------------------| */
+
+void clear_reception ()
+{
+  int i=0 ;
+  for ( i=0;i<4;i++) { 
+    car_precedent_est_escape[i] = 0 ; 
+    indice_reception[i]=0 ;
+    indice_reception_fin_fr[i]=0 ;
+  } ;
+}
+
+/* |-----------------------------------------------------------------------| */
+/* | teste le retour en mode videotex                                      | */
+/* | la sequence de fin utilise dans 3617 sirene                           | */
+/* |-----------------------------------------------------------------------| */
+
+int test_retour_videotex ( car , m )
+     char car ;
+{
+
+  fprintf (stderr, "teleinfo: %x %d %d\n", car,indice_reception,indice_reception_fin_fr) ;
+
+  /* Test de reception de la chaine de retour en Videotex (ESC [?{) */
+  if (*(passage_videotex+indice_reception[m]) == car) {
+    if (indice_reception[m] == 3) {
+      return 1 ;
+    } else {
+      indice_reception[m]++ ;
+    }
+  } else {
+    indice_reception[m] = 0 ;
+  }
+  /* Test de reception de la chaine de fin du mode teleinfo 2  */
+  if (*(fin_mode_teleinfo_fr+indice_reception_fin_fr[m]) == car) {
+    if (indice_reception_fin_fr[m] == 3) {
+      return 2 ;
+    } else {
+      indice_reception_fin_fr[m] ++ ;
+    } 
+  } else {
+    indice_reception_fin_fr[m]=0 ;
+  }
+  /* -------------- */
+  return 0 ;
+}
