@@ -17,7 +17,7 @@
  *   along with this program; if not, write to the Free Software
  *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
-static char rcsid[] = "$Id: xaw.c,v 1.19 1998/10/02 15:07:11 pierre Exp $";
+static char rcsid[] = "$Id: xaw.c,v 1.23 1999/09/17 07:16:04 pierre Exp $";
 
 /*
  * Couche Toolkit ATHENA
@@ -112,8 +112,10 @@ static char rcsid[] = "$Id: xaw.c,v 1.19 1998/10/02 15:07:11 pierre Exp $";
 #define SAUVE            	0
 #define CHARGE           	1
 #define IMPRIME           	2
-#define LIGNE_BLANCHE		3
-#define QUITTE           	4
+#define TERMINAL           	3
+#define RACCROCHER           	4
+#define LIGNE_BLANCHE		5
+#define QUITTE           	6
 #define NOUVEAU            	0
 #define DEMARRE           	1
 #define ARRETE          	2
@@ -124,6 +126,8 @@ static String entree_fichier[] = {
     "sauve",
     "charge",
     "imprime",
+    "terminal",
+    "raccrocher",
     "blanc",
     "quitte",
     NULL
@@ -176,10 +180,14 @@ static String *pixmaps_minitel_on[] = {
 #endif
 
 static void PopupSousMenu(), PopdownSousMenu();
+static void PopupSousMenu2(), PopdownSousMenu2();
 
 static XtActionsRec actions[] = {
     {"PopupSousMenu", (XtActionProc)PopupSousMenu},
-    {"PopdownSousMenu", (XtActionProc)PopdownSousMenu}
+    {"PopdownSousMenu", (XtActionProc)PopdownSousMenu},
+    {"PopupSousMenu2", (XtActionProc)PopupSousMenu2},
+    {"PopdownSousMenu2", (XtActionProc)PopdownSousMenu2}
+
 }; 
 
 static char *toolkit = "Athena";
@@ -188,7 +196,7 @@ static int n;
 static char buf[256];
 static Widget em, top;
 static Widget bouton_enregistrement, menu_enregistrement;
-static Widget bouton_fichier, menu_fichier, menu_compose, menu_procedure;
+static Widget bouton_fichier, menu_compose, menu_procedure;
 static Widget forme_base, nouveau, lecteur;
 static Widget popup_sortie, popup_saisie, popup_erreur, quitte_lecteur, titre_arret_lecteur;
 static Widget boite_saisie, confirmation_sortie, message_erreur;
@@ -205,8 +213,8 @@ static Widget menu_proto, paned_base;
 #ifndef LOW_MEMORY
 static Widget boite_haut, btn_enregistre, btn_lecteur, btn_quitte;
 #endif /* LOW_MEMORY */
-static Widget popup_impression, bouton_imprime;
-static Boolean popup_actif;
+static Widget popup_impression, bouton_imprime, bouton_terminal;
+static Boolean popup_actif, popup2_actif;
 static Cursor hand_cursor;
 
 #ifdef NOTDEF
@@ -274,6 +282,7 @@ XtPointer call_data;
     XtVaSetValues (type_arret_lecteur, XtNlabel, value, NULL);
 }
 
+/* Affichage/effacement du sous-menu d'impression */
 static void
 PopupSousMenu (w, pevent, params, nb_params)
 Widget          w;
@@ -288,7 +297,7 @@ Cardinal        nb_params;
     XtTranslateCoords (bouton_imprime, x, y, &x_root, &y_root);
 
     if (!popup_actif && (pevent->x > width && pevent->y > y) && pevent->y < (y + height)) {
-	XtVaSetValues (popup_impression, XtNx, x_root + width + 1, XtNy, pevent->y_root, NULL);
+	XtVaSetValues (popup_impression, XtNx, x_root + width + 1, XtNy, y_root - 2*height, NULL);
 	XtPopup (popup_impression, XtGrabNonexclusive);
 	popup_actif = True;
     }
@@ -307,6 +316,40 @@ Cardinal        nb_params;
     }
 }
 
+/* Affichage/effacement du sous-menu de slection de terminal */
+static void
+PopupSousMenu2 (w, pevent, params, nb_params)
+Widget          w;
+XCrossingEvent  *pevent;
+String         *params;
+Cardinal        nb_params;
+{
+    Dimension width, height;
+    Position x, y, x_root, y_root;
+
+    XtVaGetValues (bouton_terminal, XtNwidth, &width, XtNheight, &height, XtNx, &x, XtNy, &y, NULL);
+    XtTranslateCoords (bouton_terminal, x, y, &x_root, &y_root);
+
+    if (!popup2_actif && (pevent->x > width && pevent->y > y) && pevent->y < (y + height)) {
+	XtVaSetValues (menu_terminal, XtNx, x_root + width + 1, XtNy, y_root - 3*height, NULL);
+	XtPopup (menu_terminal, XtGrabNonexclusive);
+	popup2_actif = True;
+    }
+}
+
+static void
+PopdownSousMenu2 (w, pevent, params, nb_params)
+Widget          w;
+XCrossingEvent  *pevent;
+String         *params;
+Cardinal        nb_params;
+{
+    if (popup2_actif) {
+	XtPopdown (menu_terminal);
+	popup2_actif = False;
+    }
+}
+
 /*
  * Creation d'une entree menu
  */
@@ -482,11 +525,20 @@ Widget topLevel;
       if (i == LIGNE_BLANCHE)
 	(void)XtCreateManagedWidget(item, smeLineObjectClass, menu_fichier, NULL, 0);
       else {
-	entry = create_menu_entry (menu_fichier, item, Selection_menu_fichier, (XtPointer)i);
+	if (i == RACCROCHER) {
+	  if (rsc_xtel.boutonRaccrocher)
+	    entry = create_menu_entry (menu_fichier, "raccrocher", (XtCallbackProc)raccrocher, (XtPointer)NULL);
+	}
+	else
+	  entry = create_menu_entry (menu_fichier, item, (XtCallbackProc)Selection_menu_fichier, (XtPointer)i);
 	if (i == IMPRIME) {
 	    bouton_imprime = entry;
 	    XtVaSetValues (entry, XtNrightBitmap, XCreateBitmapFromData (XtDisplay(topLevel), XtScreen(topLevel)->root, submenu_bits, submenu_width, submenu_height), NULL);
 	}
+	if (i == TERMINAL) {
+	    bouton_terminal = entry;
+	    XtVaSetValues (entry, XtNrightBitmap, XCreateBitmapFromData (XtDisplay(topLevel), XtScreen(topLevel)->root, submenu_bits, submenu_width, submenu_height), NULL);
+	}
       }
     }
 
@@ -495,6 +547,10 @@ Widget topLevel;
     (void)create_menu_entry (popup_impression, "imp_ascii", (XtCallbackProc)imprime_page_courante_ascii, (XtPointer)NULL);
     (void)create_menu_entry (popup_impression, "imp_videotex", (XtCallbackProc)imprime_page_courante_videotex, (XtPointer)NULL);
 
+    menu_terminal = XtCreatePopupShell ("menu_terminal", simpleMenuWidgetClass, forme_base, NULL, 0);
+    for (i = 0 ; i < 3 ; i++)
+      (void)create_menu_entry (menu_terminal, touches[i].nom, (XtCallbackProc)selection_mode_emulation, (XtPointer)touches[i].code);
+
     /* Enregistrement */
 
     /* titre du menu */
@@ -777,7 +833,7 @@ Widget topLevel;
 	 */
 	/* "Fichier" */
 	for (i = 0;  entree_fichier[i] != NULL ; i++) {
-	    if (i != LIGNE_BLANCHE && i != QUITTE) {
+	    if (i != LIGNE_BLANCHE && i != QUITTE && i != TERMINAL && i != RACCROCHER) {
 		if (i == IMPRIME) {
 		    (void)create_pixmap_button (boite_haut, "btn_imprime_ascii", xpmButtonWidgetClass,  (XtCallbackProc)imprime_page_courante_ascii, (XtPointer)NULL, printera_xpm, None, None, None, unsensitive_pixmap_h);
 		    (void)create_pixmap_button (boite_haut, "btn_imprime", xpmButtonWidgetClass, (XtCallbackProc)imprime_page_courante_videotex, (XtPointer)NULL, printer_xpm, None, None, None, unsensitive_pixmap_h);
@@ -1259,7 +1315,13 @@ void efface_lecteur ()
 
 void affiche_lecteur ()
 {
-    XtPopup (popup_lecteur, XtGrabNone);    
+  int type_arret = atoi(rsc_xtel.typeArret);
+
+  if (type_arret < 0 || type_arret > 3) 
+    type_arret = 3;
+
+  menu_type_arret_page_cb (type_arret_lecteur, type_arret, 0);
+  XtPopup (popup_lecteur, XtGrabNone);    
 }
 
 /* Affiche les compteurs */
@@ -1283,7 +1345,6 @@ void affiche_compteur_lecteur_page ()
 }
 
 /* Force le bouton STOP valide si appel de stop_rapide() */
-
 void activation_bouton_stop ()
 {
     /* Valide le STOP, invalide la PLAY */
