@@ -17,7 +17,7 @@
  *   along with this program; if not, write to the Free Software
  *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
-static char rcsid[] = "$Id: xm.c,v 1.14 1998/10/02 15:07:42 pierre Exp $";
+static char rcsid[] = "$Id: xm.c,v 1.17 1999/09/14 11:05:21 pierre Exp $";
 
 /*
  * Couche Toolkit OSF-MOTIF
@@ -44,14 +44,8 @@ static char rcsid[] = "$Id: xm.c,v 1.14 1998/10/02 15:07:42 pierre Exp $";
 #include <Xm/Frame.h>
 #include <Xm/Label.h>
 
-#ifndef NO_XPM
 #include <X11/xpm.h>
 #include "pixmaps/pf.xpm"
-#else
-#include "bitmaps/pf.bit"
-#endif /* NO_XPM */
-
-#ifndef LOW_MEMORY
 
 #include "bitmaps/unsensitiveh.xbm"
 #include "bitmaps/unsensitiveb.xbm"
@@ -92,11 +86,6 @@ static char rcsid[] = "$Id: xm.c,v 1.14 1998/10/02 15:07:42 pierre Exp $";
 #include "pixmaps/correc_on.xpm"
 #include "pixmaps/cxfin_on.xpm"
 
-#include "Timer.h"
-#include "XpmButton.h"
-
-#endif /* !LOW_MEMORY */
-
 #include "bitmaps/teleph.xbm"
 #include "bitmaps/aide.bit"
 #include "bitmaps/lecteur.bit"
@@ -106,6 +95,9 @@ static char rcsid[] = "$Id: xm.c,v 1.14 1998/10/02 15:07:42 pierre Exp $";
 #include "bitmaps/play.bit"
 #include "bitmaps/stop.bit"
 
+#include "Timer.h"
+#include "XpmButton.h"
+
 #define XmStringDefCreate(s) XmStringLtoRCreate((s),XmSTRING_DEFAULT_CHARSET)
 #define K_Charge	0
 #define K_Sauve		1
@@ -127,7 +119,7 @@ static Widget clavier_lecteur, btn_lecteur;
 static Widget fem, em, top;
 static Widget forme_base, paned_base, menu_compose, menu_procedure, menu_impression;
 static Widget selecteur_fichier, boite_saisie, confirmation_sortie, message_erreur;
-static Widget barre_menu, menu_fichier, menu_enregistrement;
+static Widget barre_menu, menu_enregistrement;
 
 
 static void Ouverture_boite_saisie ();
@@ -241,7 +233,6 @@ int width, height;
     }
 }
 
-#ifndef NO_XPM
 /*
  * PushButton avec Pixmap XPM
  */
@@ -281,9 +272,7 @@ char *xpm_data[], *unsensitive_xpm_data[];
 	return (NULL);
     }
 }
-#endif
 
-#ifndef LOW_MEMORY
 static Widget create_xpm_button (parent, name, class, cb, call_data, pixmap1_data, pixmap2_data, shape1_data, shape2_data, unsensitive_bitmap)
 Widget parent;
 char *name;
@@ -313,7 +302,6 @@ Pixmap unsensitive_bitmap;
 
     return (w);
 }
-#endif /* !LOW_MEMORY */
 
 /*
  * PushButton avec Bitmap X
@@ -358,10 +346,13 @@ XButtonEvent *pevent;
 String *params;
 Cardinal nb_params;
 {
+#ifndef DONT_USE_POPUP
     XmMenuPosition(menu_clavier, pevent);
     XtManageChild (menu_clavier);
+#endif
 }
 
+
 /*
  * Initialisation du toolkit 
  */
@@ -377,7 +368,9 @@ char **argv;
 
     top = XtAppInitialize(&app_context, "XTelm", options, XtNumber(options), pargc, argv, NULL, NULL, 0);
 
+#ifndef DONT_USE_POPUP
     XtAppAddActions(app_context, actions_touches, XtNumber(actions_touches));
+#endif
 
     return (top);
 }
@@ -392,8 +385,9 @@ Widget topLevel;
     Widget entry;
     XpmAttributes xpma;
 #ifndef LOW_MEMORY
-    Pixmap unsensitive_pixmap_h, unsensitive_pixmap_b;
+    Pixmap unsensitive_pixmap_h, unsensitive_pixmap_b, pixmap_k7;
 #endif
+    int type_arret;
 
 #ifdef DEBUG
     printf ("Initialisation des widgets\n");
@@ -404,7 +398,6 @@ Widget topLevel;
     /* Contenant de base */
     forme_base = XtVaCreateManagedWidget ("forme_base", xmRowColumnWidgetClass, topLevel, XmNorientation, XmVERTICAL, XmNentryAlignment, XmALIGNMENT_CENTER, NULL);
 
-
     /* Barre de menu */
     n = 0;
     XtSetArg (args[n], XmNmenuHelpWidget, bouton_aide); n++;
@@ -413,12 +406,22 @@ Widget topLevel;
     /* Menu "Fichier" */
     menu_fichier = XmCreatePulldownMenu (barre_menu, "menu_fichier", NULL, 0);
     menu_impression = XmCreatePulldownMenu (topLevel, "menu_impression", NULL, 0);
+    menu_terminal = XmCreatePulldownMenu (topLevel, "menu_terminal", NULL, 0);
     XtVaCreateManagedWidget ("bouton_fichier", xmCascadeButtonWidgetClass, barre_menu, XmNsubMenuId, menu_fichier, NULL);
     create_menu_entry (menu_fichier, "bouton_sauve", True, Ouverture_selecteur_fichier, (XTPOINTER)K_Sauve);
     entry = create_menu_entry (menu_fichier, "bouton_charge", True, Ouverture_selecteur_fichier, (XTPOINTER)K_Charge);
     XtVaCreateManagedWidget ("bouton_imprime", xmCascadeButtonWidgetClass, menu_fichier, XmNsubMenuId, menu_impression, NULL);
     create_menu_entry (menu_impression, "bouton_impression_ascii", True, imprime_page_courante_ascii, NULL);
     create_menu_entry (menu_impression, "bouton_impression_videotex", True, imprime_page_courante_videotex, NULL);
+
+    XtVaCreateManagedWidget ("bouton_terminal", xmCascadeButtonWidgetClass, menu_fichier, XmNsubMenuId, menu_terminal, NULL);
+    create_menu_entry (menu_terminal, "videotex", False, selection_mode_emulation, (XTPOINTER)"V");
+    create_menu_entry (menu_terminal, "teleinfo_ascii", True, selection_mode_emulation, (XTPOINTER)"A");
+    create_menu_entry (menu_terminal, "teleinfo_fr", True, selection_mode_emulation, (XTPOINTER)"F");
+
+    if (rsc_xtel.boutonRaccrocher)
+      create_menu_entry (menu_fichier, "raccrocher", False, raccrocher, NULL);
+
     XtVaCreateManagedWidget ("separateur_fichier", xmSeparatorGadgetClass, menu_fichier, NULL);
     create_menu_entry (menu_fichier, "bouton_quitte", True, Ouverture_confirmation_sortie, NULL);
 
@@ -482,43 +485,36 @@ Widget topLevel;
 
     paned_base = XtVaCreateManagedWidget ("paned_base", xmRowColumnWidgetClass, forme_base, XmNorientation, (rsc_xtel.petiteFonte ? XmHORIZONTAL : XmVERTICAL), XmNentryAlignment, XmALIGNMENT_CENTER, NULL);
 
-#ifndef LOW_MEMORY
-    if (!low_memory) {
-	Pixmap pixmap_k7;
+    /* Calcul des Pixmaps de masquage des boutons */
+    unsensitive_pixmap_h = XCreateBitmapFromData (XtDisplay(topLevel), DefaultRootWindow(XtDisplay(topLevel)), unsensitiveh_bits, unsensitiveh_width, unsensitiveh_height);
+    unsensitive_pixmap_b = XCreateBitmapFromData (XtDisplay(topLevel), DefaultRootWindow(XtDisplay(topLevel)), unsensitiveb_bits, unsensitiveb_width, unsensitiveb_height);
 
-	/* Calcul des Pixmaps de masquage des boutons */
-	unsensitive_pixmap_h = XCreateBitmapFromData (XtDisplay(topLevel), DefaultRootWindow(XtDisplay(topLevel)), unsensitiveh_bits, unsensitiveh_width, unsensitiveh_height);
-	unsensitive_pixmap_b = XCreateBitmapFromData (XtDisplay(topLevel), DefaultRootWindow(XtDisplay(topLevel)), unsensitiveb_bits, unsensitiveb_width, unsensitiveb_height);
+    if (rsc_xtel.petiteFonte)
+      boite_haut = XtVaCreateManagedWidget ("boite_haut", xmRowColumnWidgetClass, paned_base, XmNorientation, XmVERTICAL, XmNnumColumns, 2, XmNpacking, XmPACK_COLUMN, NULL);
+    else
+      boite_haut = XtVaCreateManagedWidget ("boite_haut", xmRowColumnWidgetClass, paned_base, XmNorientation, XmHORIZONTAL, NULL);
 
-	if (rsc_xtel.petiteFonte)
-	    boite_haut = XtVaCreateManagedWidget ("boite_haut", xmRowColumnWidgetClass, paned_base, XmNorientation, XmVERTICAL, XmNnumColumns, 2, XmNpacking, XmPACK_COLUMN, NULL);
-	else
-	    boite_haut = XtVaCreateManagedWidget ("boite_haut", xmRowColumnWidgetClass, paned_base, XmNorientation, XmHORIZONTAL, NULL);
+    (void)create_xpm_button (boite_haut, "btn_sauve", xpmButtonWidgetClass, Ouverture_selecteur_fichier, (XTPOINTER)K_Sauve, disk_write_xpm, None, None, None, unsensitive_pixmap_h);    
+    (void)create_xpm_button (boite_haut, "btn_charge", xpmButtonWidgetClass, Ouverture_selecteur_fichier, (XTPOINTER)K_Charge, disk_read_xpm, None, None, None, unsensitive_pixmap_h);    
+    (void)create_xpm_button (boite_haut, "btn_imprime_ascii", xpmButtonWidgetClass, imprime_page_courante_ascii, NULL, printera_xpm, None, None, None, unsensitive_pixmap_h);    
+    (void)create_xpm_button (boite_haut, "btn_imprime", xpmButtonWidgetClass, imprime_page_courante_videotex, NULL, printer_xpm, None, None, None, unsensitive_pixmap_h);    
+    (void)create_xpm_button (boite_haut, "btn_nouveau", xpmButtonWidgetClass, nouvel_enregistrement, NULL, nouveau_xpm, None, None, None, unsensitive_pixmap_h);
+    (void)create_xpm_button (boite_haut, "btn_enregistre", xpmButtonWidgetClass, change_enregistrement, NULL, camera_xpm, None, None, None, unsensitive_pixmap_h);
+    btn_lecteur = create_xpm_button (boite_haut, "btn_lecteur", xpmButtonWidgetClass, debut_lecteur, NULL, film_xpm, None, None, None, unsensitive_pixmap_h);
+    /* Appel direct */
+    if (nb_services >= 1 && strcmp (entree_compose[nb_services-1], "Direct") == 0)
+      btn_direct = create_xpm_button (boite_haut, "btn_direct", xpmButtonWidgetClass, Ouverture_boite_saisie, NULL, phone_xpm, None, None, None, unsensitive_pixmap_h);
+    (void)create_xpm_button (boite_haut, "btn_quitte", xpmButtonWidgetClass, Ouverture_confirmation_sortie, NULL, door_run_xpm, None, None, None, unsensitive_pixmap_h);
 
-
-	(void)create_xpm_button (boite_haut, "btn_sauve", xpmButtonWidgetClass, Ouverture_selecteur_fichier, (XTPOINTER)K_Sauve, disk_write_xpm, None, None, None, unsensitive_pixmap_h);    
-	(void)create_xpm_button (boite_haut, "btn_charge", xpmButtonWidgetClass, Ouverture_selecteur_fichier, (XTPOINTER)K_Charge, disk_read_xpm, None, None, None, unsensitive_pixmap_h);    
-	(void)create_xpm_button (boite_haut, "btn_imprime_ascii", xpmButtonWidgetClass, imprime_page_courante_ascii, NULL, printera_xpm, None, None, None, unsensitive_pixmap_h);    
-	(void)create_xpm_button (boite_haut, "btn_imprime", xpmButtonWidgetClass, imprime_page_courante_videotex, NULL, printer_xpm, None, None, None, unsensitive_pixmap_h);    
-	(void)create_xpm_button (boite_haut, "btn_nouveau", xpmButtonWidgetClass, nouvel_enregistrement, NULL, nouveau_xpm, None, None, None, unsensitive_pixmap_h);
-	(void)create_xpm_button (boite_haut, "btn_enregistre", xpmButtonWidgetClass, change_enregistrement, NULL, camera_xpm, None, None, None, unsensitive_pixmap_h);
-	btn_lecteur = create_xpm_button (boite_haut, "btn_lecteur", xpmButtonWidgetClass, debut_lecteur, NULL, film_xpm, None, None, None, unsensitive_pixmap_h);
-	/* Appel direct */
-	if (nb_services >= 1 && strcmp (entree_compose[nb_services-1], "Direct") == 0)
-	  btn_direct = create_xpm_button (boite_haut, "btn_direct", xpmButtonWidgetClass, Ouverture_boite_saisie, NULL, phone_xpm, None, None, None, unsensitive_pixmap_h);
-	(void)create_xpm_button (boite_haut, "btn_quitte", xpmButtonWidgetClass, Ouverture_confirmation_sortie, NULL, door_run_xpm, None, None, None, unsensitive_pixmap_h);
-
-	/* Cassette */
-	XtVaGetValues (boite_haut, XtNcolormap, &xpma.colormap, NULL);
-	xpma.valuemask = XpmColormap;
-	XpmCreatePixmapFromData (XtDisplay(boite_haut), DefaultRootWindow(XtDisplay(boite_haut)), cassete_xpm, &pixmap_k7, NULL, &xpma);
-	la_cassete = XtVaCreateManagedWidget ("la_cassete", xmLabelWidgetClass, boite_haut, XmNlabelType, XmPIXMAP, XmNmappedWhenManaged, False, XmNlabelPixmap, pixmap_k7, NULL);
-	teleph = create_bitmap_label (boite_haut, "teleph", teleph_bits, teleph_width, teleph_height);
-	/* Timer */
-	if (!rsc_xtel.petiteFonte)
-	    timer_minitel = XtVaCreateManagedWidget ("timer_minitel", timerWidgetClass, boite_haut, NULL);
-    }
-#endif
+    /* Cassette */
+    XtVaGetValues (boite_haut, XtNcolormap, &xpma.colormap, NULL);
+    xpma.valuemask = XpmColormap;
+    XpmCreatePixmapFromData (XtDisplay(boite_haut), DefaultRootWindow(XtDisplay(boite_haut)), cassete_xpm, &pixmap_k7, NULL, &xpma);
+    la_cassete = XtVaCreateManagedWidget ("la_cassete", xmLabelWidgetClass, boite_haut, XmNlabelType, XmPIXMAP, XmNmappedWhenManaged, False, XmNlabelPixmap, pixmap_k7, NULL);
+    teleph = create_bitmap_label (boite_haut, "teleph", teleph_bits, teleph_width, teleph_height);
+    /* Timer */
+    if (!rsc_xtel.petiteFonte)
+      timer_minitel = XtVaCreateManagedWidget ("timer_minitel", timerWidgetClass, boite_haut, NULL);
 
     /*
      * Creation du lecteur
@@ -539,25 +535,11 @@ Widget topLevel;
     XtManageChild (clavier_lecteur);
 
     /* Les boutons de commandes */
-#ifndef LOW_MEMORY
-    if (low_memory)
-#endif /* !LOW_MEMORY */
-	{
-	    create_bitmap_button (clavier_lecteur, "rewind_lecteur", xmToggleButtonWidgetClass, Rewind_lecteur, Valide_le_bouton_stop, NULL, NULL, zero_bits, zero_width, zero_height);
-	    create_bitmap_button (clavier_lecteur, "rewind_lecteur", xmToggleButtonWidgetClass, Rewind_lecteur, Valide_le_bouton_stop, NULL, NULL, rewind_bits, rewind_width, rewind_height);
-	    stop_lecteur = create_bitmap_button (clavier_lecteur, "stop_lecteur", xmToggleButtonWidgetClass, Stop_lecteur, NULL, NULL, NULL, stop_bits, stop_width, stop_height);
-	    play_lecteur = create_bitmap_button (clavier_lecteur, "play_lecteur", xmToggleButtonWidgetClass, Play_lecteur, NULL, NULL, NULL, play_bits, play_width, play_height);
-	    create_bitmap_button (clavier_lecteur, "wind_lecteur", xmToggleButtonWidgetClass, Wind_lecteur, Valide_le_bouton_stop, NULL, NULL, wind_bits, wind_width, wind_height);
-	}
-#ifndef LOW_MEMORY
-    else {
-	create_pixmap_button (clavier_lecteur, "zero_lecteur", True, xmToggleButtonWidgetClass, Rewind_lecteur, Valide_le_bouton_stop, NULL, NULL, rewind_xpm, NULL);
-	create_pixmap_button (clavier_lecteur, "rewind_lecteur", True, xmToggleButtonWidgetClass, Rewind_lecteur, Valide_le_bouton_stop, NULL, NULL, prev_xpm, NULL);
-	stop_lecteur = create_pixmap_button (clavier_lecteur, "stop_lecteur", True, xmToggleButtonWidgetClass, Stop_lecteur, NULL, NULL, NULL, stop_xpm, NULL);
-	play_lecteur = create_pixmap_button (clavier_lecteur, "play_lecteur", True, xmToggleButtonWidgetClass, Play_lecteur, NULL, NULL, NULL, play_xpm, NULL);
-	create_pixmap_button (clavier_lecteur, "wind_lecteur", True, xmToggleButtonWidgetClass, Wind_lecteur, Valide_le_bouton_stop, NULL, NULL, next_xpm, NULL);
-    }
-#endif /* !LOW_MEMORY */
+    create_pixmap_button (clavier_lecteur, "zero_lecteur", True, xmToggleButtonWidgetClass, Rewind_lecteur, Valide_le_bouton_stop, NULL, NULL, rewind_xpm, NULL);
+    create_pixmap_button (clavier_lecteur, "rewind_lecteur", True, xmToggleButtonWidgetClass, Rewind_lecteur, Valide_le_bouton_stop, NULL, NULL, prev_xpm, NULL);
+    stop_lecteur = create_pixmap_button (clavier_lecteur, "stop_lecteur", True, xmToggleButtonWidgetClass, Stop_lecteur, NULL, NULL, NULL, stop_xpm, NULL);
+    play_lecteur = create_pixmap_button (clavier_lecteur, "play_lecteur", True, xmToggleButtonWidgetClass, Play_lecteur, NULL, NULL, NULL, play_xpm, NULL);
+    create_pixmap_button (clavier_lecteur, "wind_lecteur", True, xmToggleButtonWidgetClass, Wind_lecteur, Valide_le_bouton_stop, NULL, NULL, next_xpm, NULL);
 
     XtVaSetValues (stop_lecteur, XmNset, True, NULL);
 
@@ -578,8 +560,13 @@ Widget topLevel;
     XtManageChild (compteur_lecteur_page);
 
     /* Condition d'arret */
-    menu_type_arret_page = XmVaCreateSimpleOptionMenu (rc_lecteur, "menu_type_arret_page", NULL, 0, 0, (XtCallbackProc)menu_type_arret_page_cb, XmVaPUSHBUTTON, NULL, 0, NULL, NULL, XmVaPUSHBUTTON, NULL, 0, NULL, NULL, XmVaPUSHBUTTON, NULL, 0, NULL, NULL, XmVaPUSHBUTTON, NULL, 0, NULL, NULL, NULL); 
+    type_arret = atoi(rsc_xtel.typeArret);
+    if (type_arret < 0 || type_arret > 3) 
+      type_arret = 3;
+
+    menu_type_arret_page = XmVaCreateSimpleOptionMenu (rc_lecteur, "menu_type_arret_page", NULL, 0, type_arret, (XtCallbackProc)menu_type_arret_page_cb, XmVaPUSHBUTTON, NULL, 0, NULL, NULL, XmVaPUSHBUTTON, NULL, 0, NULL, NULL, XmVaPUSHBUTTON, NULL, 0, NULL, NULL, XmVaPUSHBUTTON, NULL, 0, NULL, NULL, NULL); 
     XtManageChild (menu_type_arret_page);
+    menu_type_arret_page_cb (menu_type_arret_page, type_arret, 0);
 
     /* Bouton 'Quitte' */
     n = 0;
@@ -608,10 +595,7 @@ Widget topLevel;
     if (rsc_xtel.petiteFonte) {
 	XtSetArg (args[n], XtNpetiteFonte, True);
 	n++;
-#ifndef LOW_MEMORY
-	if (!low_memory)
-	    entry = XtVaCreateManagedWidget ("pem", xmRowColumnWidgetClass, paned_base, XmNorientation, XmVERTICAL, NULL);
-#endif
+	entry = XtVaCreateManagedWidget ("pem", xmRowColumnWidgetClass, paned_base, XmNorientation, XmVERTICAL, NULL);
     }
 
     /* Id de ROM */
@@ -626,11 +610,9 @@ Widget topLevel;
     XtManageChild (fem);
     em = XtCreateManagedWidget ("ecran_minitel", videotexWidgetClass, fem, args, n);
 
-#ifndef LOW_MEMORY
     /* Timer */
     if (rsc_xtel.petiteFonte && !low_memory)
 	timer_minitel = XtVaCreateManagedWidget ("timer_minitel", timerWidgetClass, entry, NULL);
-#endif
 
     /* Popup-menu du clavier Minitel */
     n = 0;
@@ -654,21 +636,17 @@ Widget topLevel;
     if (rsc_xtel.boutonRaccrocher)
 	create_menu_entry (menu_clavier, "raccrocher", False, raccrocher, NULL);
 
-#ifndef LOW_MEMORY
-    if (!low_memory) {
-	boite_bas = XtVaCreateManagedWidget ("boite_bas", xmRowColumnWidgetClass, paned_base, XmNorientation, (rsc_xtel.petiteFonte ? XmVERTICAL : XmHORIZONTAL), NULL);
+    boite_bas = XtVaCreateManagedWidget ("boite_bas", xmRowColumnWidgetClass, paned_base, XmNorientation, (rsc_xtel.petiteFonte ? XmVERTICAL : XmHORIZONTAL), NULL);
 	
-	(void)create_xpm_button (boite_bas, "btn_envoi", xpmButtonWidgetClass, (XtCallbackProc)commandes, (XtPointer)"A", envoi_xpm, envoi_on_xpm, envoi_xpm, envoi_on_xpm, unsensitive_pixmap_b);
-	(void)create_xpm_button (boite_bas, "btn_retour", xpmButtonWidgetClass, (XtCallbackProc)commandes, (XtPointer)"B", retour_xpm, retour_on_xpm, retour_xpm, retour_on_xpm, unsensitive_pixmap_b);
-	(void)create_xpm_button (boite_bas, "btn_repetition", xpmButtonWidgetClass, (XtCallbackProc)commandes, (XtPointer)"C", repet_xpm, repet_on_xpm, repet_xpm, repet_on_xpm, unsensitive_pixmap_b);
-	(void)create_xpm_button (boite_bas, "btn_guide", xpmButtonWidgetClass, (XtCallbackProc)commandes, (XtPointer)"D", guide_xpm, guide_on_xpm, guide_xpm, guide_on_xpm, unsensitive_pixmap_b);
-	(void)create_xpm_button (boite_bas, "btn_annulation", xpmButtonWidgetClass, (XtCallbackProc)commandes, (XtPointer)"E", annul_xpm, annul_on_xpm, annul_xpm, annul_on_xpm, unsensitive_pixmap_b);
-	(void)create_xpm_button (boite_bas, "btn_sommaire", xpmButtonWidgetClass, (XtCallbackProc)commandes, (XtPointer)"F", sommaire_xpm, sommaire_on_xpm, sommaire_xpm, sommaire_on_xpm, unsensitive_pixmap_b);
-	(void)create_xpm_button (boite_bas, "btn_correction", xpmButtonWidgetClass, (XtCallbackProc)commandes, (XtPointer)"G", correc_xpm, correc_on_xpm, correc_xpm, correc_on_xpm, unsensitive_pixmap_b);
-	(void)create_xpm_button (boite_bas, "btn_suite", xpmButtonWidgetClass, (XtCallbackProc)commandes, (XtPointer)"H", suite_xpm, suite_on_xpm, suite_xpm, suite_on_xpm, unsensitive_pixmap_b);
-	(void)create_xpm_button (boite_bas, "btn_connexion_fin", xpmButtonWidgetClass, (XtCallbackProc)commandes, (XtPointer)"I", cxfin_xpm, cxfin_on_xpm, cxfin_xpm, cxfin_on_xpm, unsensitive_pixmap_b);
-    }
-#endif /* !LOW_MEMORY */
+    (void)create_xpm_button (boite_bas, "btn_envoi", xpmButtonWidgetClass, (XtCallbackProc)commandes, (XtPointer)"A", envoi_xpm, envoi_on_xpm, envoi_xpm, envoi_on_xpm, unsensitive_pixmap_b);
+    (void)create_xpm_button (boite_bas, "btn_retour", xpmButtonWidgetClass, (XtCallbackProc)commandes, (XtPointer)"B", retour_xpm, retour_on_xpm, retour_xpm, retour_on_xpm, unsensitive_pixmap_b);
+    (void)create_xpm_button (boite_bas, "btn_repetition", xpmButtonWidgetClass, (XtCallbackProc)commandes, (XtPointer)"C", repet_xpm, repet_on_xpm, repet_xpm, repet_on_xpm, unsensitive_pixmap_b);
+    (void)create_xpm_button (boite_bas, "btn_guide", xpmButtonWidgetClass, (XtCallbackProc)commandes, (XtPointer)"D", guide_xpm, guide_on_xpm, guide_xpm, guide_on_xpm, unsensitive_pixmap_b);
+    (void)create_xpm_button (boite_bas, "btn_annulation", xpmButtonWidgetClass, (XtCallbackProc)commandes, (XtPointer)"E", annul_xpm, annul_on_xpm, annul_xpm, annul_on_xpm, unsensitive_pixmap_b);
+    (void)create_xpm_button (boite_bas, "btn_sommaire", xpmButtonWidgetClass, (XtCallbackProc)commandes, (XtPointer)"F", sommaire_xpm, sommaire_on_xpm, sommaire_xpm, sommaire_on_xpm, unsensitive_pixmap_b);
+    (void)create_xpm_button (boite_bas, "btn_correction", xpmButtonWidgetClass, (XtCallbackProc)commandes, (XtPointer)"G", correc_xpm, correc_on_xpm, correc_xpm, correc_on_xpm, unsensitive_pixmap_b);
+    (void)create_xpm_button (boite_bas, "btn_suite", xpmButtonWidgetClass, (XtCallbackProc)commandes, (XtPointer)"H", suite_xpm, suite_on_xpm, suite_xpm, suite_on_xpm, unsensitive_pixmap_b);
+    (void)create_xpm_button (boite_bas, "btn_connexion_fin", xpmButtonWidgetClass, (XtCallbackProc)commandes, (XtPointer)"I", cxfin_xpm, cxfin_on_xpm, cxfin_xpm, cxfin_on_xpm, unsensitive_pixmap_b);
 
     return (em);
 }
@@ -872,16 +850,12 @@ XtPointer client_data, call_data;
     Pixmap pixmap_pf;
 
     if (!flag_copyright_affiche) {
-#ifndef NO_XPM
 	XpmAttributes xpma;
 
 	XtVaGetValues (w, XtNcolormap, &xpma.colormap, NULL);
 	xpma.valuemask = XpmColormap;
 
 	XpmCreatePixmapFromData (XtDisplay(top), XtWindow(top), pf_xpm, &pixmap_pf, NULL, &xpma);
-#else
-	pixmap_pf = XCreateBitmapFromData (XtDisplay(top), XtWindow(top), pf_bits, pf_width, pf_height);
-#endif /* NO_XPM */
 	affiche_copyright (top, xmFormWidgetClass, pixmap_pf);
     }
 }
@@ -924,10 +898,7 @@ XtPointer client_data, call_data;
     flag_enregistrement = 1;
     XtSetSensitive (bouton_demarre, False);
     XtSetSensitive (bouton_arrete, True);
-#ifndef LOW_MEMORY
-    if (!low_memory)
-	XtMapWidget (la_cassete);
-#endif
+    XtMapWidget (la_cassete);
 }
 
 static void arrete_enregistrement (w, client_data, call_data)
@@ -937,10 +908,7 @@ XtPointer client_data, call_data;
     flag_enregistrement = 0;
     XtSetSensitive (bouton_demarre, True);
     XtSetSensitive (bouton_arrete, False);
-#ifndef LOW_MEMORY
-    if (!low_memory)
-	XtUnmapWidget (la_cassete);
-#endif
+    XtUnmapWidget (la_cassete);
 }
 
 static void change_enregistrement (w, client_data, call_data)
@@ -985,10 +953,7 @@ void lecteur_valide (flag)
 char flag;
 {
     XtSetSensitive (bouton_lecteur, flag);
-#ifndef LOW_MEMORY
-    if (!low_memory)
-	XtSetSensitive (btn_lecteur, flag);
-#endif /* LOW_MEMORY */
+    XtSetSensitive (btn_lecteur, flag);
 }
 
 /* Affiche/efface le lecteur */
