@@ -17,7 +17,7 @@
  *   along with this program; if not, write to the Free Software
  *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
-static char rcsid[] = "$Id: xtel.c,v 1.19 1999/09/07 13:55:37 pierre Exp $";
+static char rcsid[] = "$Id: xtel.c,v 1.20 2001/02/11 00:05:13 pierre Exp $";
 
 /*
  * programme principal 
@@ -47,7 +47,7 @@ static Cursor teleph_cursor;
 static Pixmap pixmap_icone = None;
 static Boolean flag_execution = False;
 static char *procedure_executee = NULL;
-static char *copyright_string = "(C)1991-99 LECTRA-SYSTEMES & Pierre Ficheux";
+static char *copyright_string = "\n(C)1991-1998 LECTRA-SYSTEMES & Pierre Ficheux\n(C)1999-2001 Pierre Ficheux";
 static XColor black, white;
 
 /* liste des noms des boutons MINITEL */
@@ -121,6 +121,7 @@ static Boolean defaultFalse = False;
 #define XtNerreur1			"erreur1"
 #define XtNerreur2			"erreur2"
 #define XtNerreur3			"erreur3"
+#define XtNerreur4			"erreur4"
 
 #define XtNtypeArret			"typeArret"
 #define XtCTypeArret			"TypeArret"
@@ -280,6 +281,13 @@ static XtResource ressources[] = {
 	XtRString, sizeof(String),
 	XtOffsetOf(ressources_xtel, erreur[2]),
 	XtRString, (XtPointer) "Erreur 2"
+    },
+    {
+	XtNerreur4,
+	XtCString,
+	XtRString, sizeof(String),
+	XtOffsetOf(ressources_xtel, erreur[3]),
+	XtRString, (XtPointer) "Erreur 3"
 	}
 
   };
@@ -440,9 +448,10 @@ char **av;
 
     if (prototype_xtel == 0) {
 	if (PATCHLEVEL != 0)
-	    printf ("XTEL %d.%d.%d, Emulateur MINITEL %s\n", version_xtel, revision_xtel, PATCHLEVEL, copyright_string);
+	    printf ("XTEL %d.%d.%d, Emulateur MINITEL/I-MINITEL\n", version_xtel, revision_xtel, PATCHLEVEL);
 	else
-	    printf ("XTEL %d.%d, Emulateur MINITEL %s\n", version_xtel, revision_xtel, copyright_string);
+	    printf ("XTEL %d.%d, Emulateur MINITEL/I-MINITEL\n", version_xtel, revision_xtel);
+	puts (copyright_string);
     }
     else {
 	if (PATCHLEVEL != 0)
@@ -454,11 +463,6 @@ char **av;
     taille_zone_enregistrement = 1000;
     mode_emulation = MODE_VIDEOTEX;
 
-#ifdef NO_NETWORK
-    unaddr.sun_family = AF_UNIX;
-    strcpy (unaddr.sun_path, XTEL_UNIX_PATH);
-#endif /* NO_NETWORK */
-
     /*
      * Allocation de la zone d'enregistrement par defaut
      */
@@ -527,22 +531,10 @@ char **av;
     /* 
      * Lecture des services disponibles 
      */
-#ifdef NO_NETWORK
-    if ((socket_xteld = socket (AF_UNIX, SOCK_STREAM, 0))  < 0) {
-	perror ("socket");
-	exit (1);
-    }
-
-    if (connect (socket_xteld, (struct sockaddr *)&unaddr, sizeof(unaddr)) < 0) {
-	perror ("connect");
-	exit (1);
-    }
-#else
     if ((socket_xteld = c_clientbyname(rsc_xtel.serveur, rsc_xtel.nomService)) < 0) {
 	fprintf (stderr, "Erreur de connexion au serveur XTEL...\n");
 	exit (1);
     }
-#endif /* NO_NETWORK
 
     /* Transmet le nom d'utilisateur */
     if ((pw = getpwuid(getuid())) == NULL) {
@@ -647,8 +639,11 @@ char **av;
 
     XtRealizeWidget(topLevel);
 
+    /*
     XtAddCallback (ecran_minitel, XtNmodeCallback, (XtCallbackProc)selection_mode_emulation, (XtPointer)"A");
+    XtAddCallback (ecran_minitel, XtNmodefrCallback, (XtCallbackProc)selection_mode_emulation, (XtPointer)"F");
     XtAddCallback (ecran_minitel, XtNenregCallback, (XtCallbackProc)enregistre_caractere, (XtPointer)NULL);
+    */
     init_xtel ();
 
     XtAddEventHandler (topLevel, LeaveWindowMask, False, (XtEventHandler)sauve_l_ecran, NULL);
