@@ -17,7 +17,7 @@
  *   along with this program; if not, write to the Free Software
  *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
-static char rcsid[] = "$Id: xteld.c,v 1.30 1998/10/16 08:56:06 pierre Exp $";
+static char rcsid[] = "$Id: xteld.c,v 1.33 2001/02/13 09:40:49 pierre Exp $";
 
 /*
  * Demon XTELD (communication avec le MODEM)
@@ -56,9 +56,11 @@ static char rcsid[] = "$Id: xteld.c,v 1.30 1998/10/16 08:56:06 pierre Exp $";
 #include "patchlevel.h"
 
 #include <errno.h>
+#include <dirent.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <sys/time.h>
+#include <sys/param.h>
 #include <time.h>
 #include <signal.h>
 #include <string.h>
@@ -76,35 +78,19 @@ static char rcsid[] = "$Id: xteld.c,v 1.30 1998/10/16 08:56:06 pierre Exp $";
 
 #include <sys/socket.h>
 
-#ifdef NO_NETWORK
-#include <sys/un.h>
-#include <fcntl.h>
-#ifdef sun
-#include <sys/termios.h>
-#endif /* sun */
-
-static int sock_service;
-
-#define XTELD_INPUT	sock_service
-#define XTELD_OUTPUT	sock_service
-
-#else
-
 #include <netinet/in.h>
 #include <netdb.h>
 
 #define XTELD_INPUT	0
 #define XTELD_OUTPUT	1
 
-#endif /* NO_NETWORK */
-
 static int fin_fils;
 static int pid_fils;
 static int nb_services;
 static fd_set a_lire;
 static struct timeval timeout;
 static time_t t_connexion;
-static char buf[256], buf1[256], service[256], utilisateur[256];
+static char buf[MAXPATHLEN], buf1[256], service[256], utilisateur[256];
 static char flag_connexion;
 static char parite;
 static Boolean flag_serveur_local, flag_crlf;
@@ -120,6 +106,8 @@ static struct definition_service services_hyper[MAX_SERVICES];
 static int nb_services_hyper;
 static char *peer_name;
 static int first_col;
+static Boolean iminitel_connected;
+static char iminitel_script[MAXPATHLEN];
 
 /* 
  * Table des caracteres accentues avec leurs equivalents ou approximations
@@ -149,6 +137,15 @@ static char *special_char_table[] = {
 static void display_control_line (char *);
 static void erase_control_line (int);
 
+
+static void sigsegv ()
+{
+#ifdef DEBUG_XTELD
+  log_err ("Got SIGSEGV, attempting to dump core...");
+#endif
+  abort();         
+}
+
 static void demande_fin_fils()
 {
 #ifdef DEBUG_XTELD
@@ -158,12 +155,100 @@ static void demande_fin_fils()
     fin_fils = 1;
 }
 
-static void sigsegv ()
+
+/*
+ * Teste si un couple de processus xteld pere/fils existe
+ * retourne 1 si oui.
+ */
+int check_existing_process ()
 {
-  log_err ("Got SIGSEGV");
-  exit (1);
+  DIR *dir;
+  struct dirent *de;
+  int pid, ok, ret = 0;
+  char path[MAXPATHLEN], cmd[256];
+  FILE *fp;
+
+  if (!(dir = opendir (PROC_BASE)))
+    return -1;
+
+  while (de = readdir (dir)) {
+    if (!(pid = atoi (de->d_name)) || pid == getpid() || pid == getppid()) 
+      continue;
+
+    /* Teste le nom du process */
+    sprintf(path, PROC_BASE "/%d/stat", pid);
+    if (!(fp = fopen (path,"r"))) 
+      continue;
+	
+    ok = (fscanf (fp, "%*d (%[^)]", cmd) == 1);
+    (void) fclose(fp);
+
+    if (!strcmp ("xteld", cmd)) {
+      ret = 1;
+      break;
+    }
+  }
+
+  (void) closedir(dir);  
+  
+  return ret;
 }
 
+/*
+ * Lecture du fichier d'tat I-minitel
+ */
+static int read_iminitel_file ()
+{
+  FILE *fp;
+  struct stat statb;
+  char buf[256];
+
+  if (stat (IMINITEL_FILE, &statb) < 0) {
+    /* Ne devrait pas arriver */
+    erreur_a_xtel (IMINITEL_FILE, errno);
+    exit (1);
+  }
+
+  /* Fichier non vide, on lit les parametres */
+  if (statb.st_size > 0) {
+    if (!(fp = fopen (IMINITEL_FILE, "r"))) {
+      erreur_a_xtel (IMINITEL_FILE, errno);
+      exit (1);
+    }
+
+    while (fgets (buf, sizeof(buf), fp) != NULL) {
+      buf[strlen(buf)-1] = 0;
+
+      if (buf[0] == 0)
+	continue;
+
+      putenv (strdup(buf));
+    }
+
+    fclose (fp);
+    return 1;
+  }
+  else
+    return 0;
+}
+
+static void iminitel_stop ()
+{
+  /*
+   * Si dernire connexion I-Minitel, coupe la connexion PPP
+   */
+  if (iminitel_connected && !check_existing_process ()) {
+    /* Execution du script de connexion avec option 'stop' */
+    sprintf (buf, "%s/%s stop", XTEL_LIBDIR, iminitel_script);
+#ifdef DEBUG_XTELD
+    log_debug ("execute: %s", buf);
+#endif
+    if (system (buf) != 0) {
+      erreur_a_xtel (buf, errno);
+      exit (1);
+    }
+  }
+}
 
 /*
  * Transmet une erreur a XTEL 
@@ -262,11 +347,9 @@ int indice_service, *maxtime;
 	  * l'instant.
 	  */
 
-	 
 #ifdef DEBUG_XTELD
 	 log_debug ("peer= %s user= %s pt= %s", peer_name, utilisateur, pt);
 #endif
-
 	 if (*pt == '@') {
 	   if (!strcmp (pt+1, peer_name))
 	     return 1;
@@ -529,7 +612,7 @@ char *service_teletel;
       code_teletel = service_teletel;
 
 #ifdef DEBUG_XTELD
-    log_debug ("appel_service: service_teletel= %s code_teletel= %s utilisateur= %s", service_teletel, code_teletel, utilisateur);
+    log_debug ("appel_service: device_associe= [%s] service_teletel= %s code_teletel= %s utilisateur= %s", device_associe, service_teletel, code_teletel, utilisateur);
 #endif
 
     /* Service local par "pipe" */
@@ -603,24 +686,89 @@ char *service_teletel;
 	}
     }
     else 
-#ifndef NO_NETWORK
-      /* Connexion TCP */
-      if (strncmp (device_associe, "@tcp", 4) == 0) {
+    /* 
+     * Connexion TCP ou I-Minitel 3622 
+     *
+     * Pour I-Minitel le parametre est constitu du script de connexion et du port
+     * ex: connect_iminitel.sh:7516
+     */
+
+      if (!strncmp (device_associe, "@tcp", 4) || !strncmp (device_associe, "@imi", 4)) {
+	char *tcp_port;
+	int maxtime;
+	struct stat statb;
+
 	/* Valide la saisie */
 	saisie_active = 1;
 	
-	/* Recupere les parametres */
-	option = separe_chaine (code_teletel, ':');
-	if (is_number (option)) {
-	  fd_modem = c_clientbyport (code_teletel, atoi(option));
+	/* Recupere le numero de port ou nom de service + le nom du serveur */
+	tcp_port = separe_chaine (code_teletel, ':');
+
+	/* En cas de connexion I-Minitel, on effectue la connexion PPP */
+	if (!strncmp (device_associe, "@imi", 4)) {
+	  strcpy (iminitel_script, code_teletel);
+
+	  /* Si pas deja connecte, on lance la connexion */
+	  if (stat (IMINITEL_FILE, &statb) < 0) {
+	    /* Execution du script de connexion avec option 'start' */
+	    sprintf (buf, "%s/%s start", XTEL_LIBDIR, iminitel_script);
+#ifdef DEBUG_XTELD
+	    log_debug ("execute: %s", buf);
+#endif
+	    if (system (buf) != 0) {
+	      erreur_a_xtel (buf, errno);
+	      exit (1);
+	    }
+	  }
+
+	  /* Temps maxi d'attente de connexion */
+	  maxtime = IMINITEL_TIMEOUT;
+
+#ifdef DEBUG_XTELD
+	  log_debug ("attente connexion: %d secondes", maxtime);
+#endif
+
+	  /* Attente connexion */
+	  do {
+	    if (read_iminitel_file () > 0)
+	      break;
+
+	    sleep (1);
+	  } while (--maxtime);
+
+	  /* Connexion */
+	  if (!maxtime) {
+	    erreur_a_xtel ("[3] Erreur connexion PPP (timeout) !", 0);
+	    exit (1);
+	  }
+	  else { /* Connect  I-Minitel */
+#ifdef DEBUG_XTELD
+	    log_debug ("Connecte  I-Minitel ! (%s)",  getenv ("IMINITEL_SERVER"));
+#endif
+	    iminitel_connected = True;
+	    strcpy (buf, getenv ("IMINITEL_SERVER"));
+	  }
 	}
-	else {
-	  fd_modem = c_clientbyname (code_teletel, option);
+	else /* Copie simplement le nom du serveur */
+	  strcpy (buf, code_teletel);
+
+#ifdef DEBUG_XTELD
+	log_debug ("tcp serveur= %s", buf);
+#endif
+
+	if (is_number (tcp_port))
+	  fd_modem = c_clientbyport (buf, atoi(tcp_port));
+	else
+	  fd_modem = c_clientbyname (buf, tcp_port);
+
+	/* Erreur de connexion TCP */
+	if (fd_modem < 0) {
+	  erreur_a_xtel (buf, errno);
+	  iminitel_stop ();
+	  exit (1);
 	}
       }
-    else
-#endif
-      { /* Connexion MODEM */
+    else { /* Connexion MODEM */
 	/*
 	 * spare tlphone et code service (nnnn:code)
 	 */
@@ -850,6 +998,8 @@ char *service_teletel;
 #ifdef DEBUG_XTELD
 	log_debug ("meurt, code = %d", code_fin);
 #endif
+	iminitel_stop ();
+
 	exit (0);
     }
     
@@ -1255,313 +1405,201 @@ main (ac, av)
 int ac;
 char **av;
 {
-    unsigned char c;
-    char *cp, *progname;
-    register int i;
-#ifdef NO_NETWORK
-    int sock_ecoute, retry;
-    static struct sockaddr_un unaddr;
-    struct stat statb;
-    int old_umask;
-#endif /* NO_NETWORK */
-    int indice_service = 0;
+  unsigned char c;
+  char *cp, *progname;
+  register int i;
+  int indice_service = 0;
 
-    progname = xtel_basename (av[0]);
-    init_debug (progname);
+  progname = xtel_basename (av[0]);
+  init_debug (progname);
 
-    signal (SIGSEGV, sigsegv);
+  signal (SIGSEGV, sigsegv);
 
     /* Lecture de la ligne de commande */
-    while (--ac) {
-	if ((cp = *++av) == NULL)
-	  break;
-	if (*cp == '-' && *++cp) {
-	  switch(*cp) {
+  while (--ac) {
+    if ((cp = *++av) == NULL)
+      break;
+    if (*cp == '-' && *++cp) {
+      switch(*cp) {
 
-	  case 'H' :
+      case 'H' :
 #ifdef DEBUG_XTELD
-	    log_debug ("Option Windaube/HyperTerminal active !");
+	log_debug ("Option Windaube/HyperTerminal active !");
 #endif
-	    type_client = CLIENT_W_HYPER;
-	    break;
+	type_client = CLIENT_W_HYPER;
+	break;
 		      
-	  case 'v' : /* Version */
+      case 'v' : /* Version */
 
-	    fprintf (stderr, "%s for xtel version %d.%d.%d\n", progname, version_xtel, revision_xtel, PATCHLEVEL);
-	    exit (0);
+	fprintf (stderr, "%s for xtel version %d.%d.%d\n", progname, version_xtel, revision_xtel, PATCHLEVEL);
+	exit (0);
 	    
-	  default:
-	    usage (progname);
-	    break;
+      default:
+	usage (progname);
+	break;
+      }
+    }
+    else {
+      break;
+    }
+  }
+
+  if ((nb_lignes = lecture_configuration_lignes ()) < 0) {
+    exit (1);
+  }
+
+  if ((nb_services = lecture_services ()) < 0) {
+    exit (1);
+  }
+
+
+  /* Lecture du nom du client connecte */
+  peer_name = get_peer_name ();
+
+#ifdef DEBUG_XTELD
+  log_debug ("Connexion XTEL...");
+#endif
+
+  /* Lecture du nom d'utilisateur */
+  switch (type_client) {
+
+  case CLIENT_W_HYPER:
+    if (lire_initial_hyper (utilisateur) < 0)
+      goto fin_xteld;
+
+    appel_service (service);
+    break;
+
+  case CLIENT_XTEL :
+    if (lire_chaine (utilisateur) < 0)
+      goto fin_xteld;
+		
+    break;
+
+  default :
+    goto fin_xteld;
+    break;
+  }
+
+  /* lecture connexion XTEL */
+  while (!fin_connexion) {
+    if (read (XTELD_INPUT, &c, 1) <= 0) {
+      if (errno == EINTR)
+	continue;
+      else
+	break;
+    }
+
+#ifdef DEBUG_XTELD
+    if (c >= ' ')
+      log_debug("Recu de xtel: `%c' (%02x)", c, c & 255);
+    else
+      log_debug("Recu de xtel: %02x", c & 255);
+#endif
+
+
+    if (flag_connexion) {
+      if (c == VALEUR_COMMANDE_FIN) {
+#ifdef DEBUG_XTELD
+	log_debug ("tue le fils");
+#endif		      
+	kill (pid_fils, SIGTERM);
+      }
+      else {
+#ifdef NO_TERMIO
+	if (parite != SANS) {
+	  register int p;
+	  /* Calcul de parite... */			
+	  p = (c & 0x0f) ^ (c >> 4);
+	  p = (p & 3) ^ (p >> 2);      
+	  p = (p & 1) ^ (p >> 1);
+	  if (parite == IMPAIR)
+	    p = ~p;
+	  c = (c & 0x7f) | (p << 7);
+	}
+#endif /* NO_TERMIO */
+	/*
+	 * on crit sur le modem que lorsque le code de service
+	 * a t entr o qu'il n'y en a pas.
+	 */
+	if (flag_serveur_local)
+	  write ( tuyau_out[1], &c, 1 );
+	else
+	  if (saisie_active) {
+#ifdef DEBUG_XTELD
+	    if (c >= ' ')
+	      log_debug("Emission PAD: `%c' (%02x)", c, c & 255);
+	    else
+	      log_debug("Emission PAD: %02x", c & 255);
+#endif
+	    write ( fd_modem, &c, 1);
+	  }
+#ifdef DEBUG_XTELD
+	  else
+	    log_debug( "saisie perdue : `%c' (%d)", c, c );
+#endif
+      }
+    }
+    else {
+      switch (c) {
+			
+      case VALEUR_COMMANDE_CONNEXION_M1 :
+
+	appel_service (NULL);
+	break;
+
+      case VALEUR_COMMANDE_DEMANDE_CONNEXION :
+			  
+	/* lecture du service */
+	if (lire_chaine(service) < 0)
+	  fin_connexion++;
+	else
+	  /* connexion */
+	  appel_service (service);
+			  
+	break;
+			  
+      case VALEUR_COMMANDE_SERVICE_SUIVANT :
+			    
+	if ((indice_service == nb_services) || flag_m1)
+	  write (XTELD_OUTPUT, CHAINE_REPONSE_PLUS_DE_SERVICE, 1);
+	else {
+	  if (service_autorise (indice_service, &temps_maxi)) {
+	    c = strlen (definition_services[indice_service].nom_service);
+	    write (XTELD_OUTPUT, &c, 1);
+	    write (XTELD_OUTPUT, definition_services[indice_service].nom_service, c);
+#ifdef DEBUG_XTELD
+	    log_debug ("service: %s", definition_services[indice_service].nom_service);
+#endif		      
+	  }
+	  else { /* service interdit */
+	    c = 0;
+	    write (XTELD_OUTPUT, &c, 1);
+	    indice_service++;
 	  }
 	}
-	else {
-	    break;
-	}
-    }
-
-    if ((nb_lignes = lecture_configuration_lignes ()) < 0) {
-	exit (1);
-    }
-
-    if ((nb_services = lecture_services ()) < 0) {
-	exit (1);
-    }
-
-#ifdef NO_NETWORK
-
-    /* Test de l'existence de /tmp/.xtel */
-    if (stat (XTEL_UNIX_PATH, &statb) == 0) {
-	if (unlink (XTEL_UNIX_PATH) < 0) {
-	    log_err ("unlink: %m");
-	    exit (1);
-	}
-    }
-
-    /* Je deviens un petit demon... */
-    if (fork())
-	exit (0);
-
-    /*
-     * Detachement du tty
-     */
-
-#if defined(SYSV) || defined(SVR4)
-    setpgrp ();
-#else
-    setpgrp (0, getpid());
-#endif
-
-    close (0); 
-    close (1);
-    close (2);
-
-#ifndef SYSV386
-#if defined(SYSV) || defined(SVR4) || defined(linux)
-    if ((i = open ("/dev/tty", O_RDWR | O_NOCTTY)) >= 0) {
-#else
-    if ((i = open ("/dev/tty", O_RDWR)) >= 0) {	
-	(void) ioctl (i, TIOCNOTTY, (char *) 0);    /* detachement, BSD style */
-#endif /* SYSV || SVR4 */
-	(void) close (i);
-    }
-#endif /* !SYSV386 */
-
-    /*
-     * Creation/configuration de la socket d'ecoute
-     */
-
-    if ((sock_ecoute = socket (AF_UNIX, SOCK_STREAM, 0))  < 0) {
-	log_err("socket: %m");
-	exit (1);
-    }
-
-    old_umask = umask (0);
-    unaddr.sun_family = AF_UNIX;
-    strcpy (unaddr.sun_path, XTEL_UNIX_PATH);
-
-    if (bind (sock_ecoute, (struct sockaddr *)&unaddr, sizeof(unaddr)) < 0) {
-	log_err ("bind: %m");
-	exit (1);
-    }
-
-    /* Ouvre le service */
-    if (listen (sock_ecoute, 5) < 0) {
-      log_err ("listen: %m");
-      exit (1);
-    }
-
-    (void)umask (old_umask);
-
-    /*
-     * Attente de connexion...
-     */
-    for (;;) {
-
-      /* Pour eviter les zombies */
-      signal (SIGCHLD, waitchild);
-
-#ifdef DEBUG_XTELD
-	log_debug ("Attente de connexion...");
-#endif
-
-	for (retry = 10 ; ; retry--) {
-	    if ((sock_service = accept (sock_ecoute, (struct sockaddr *)NULL, (int *)NULL)) > 0) {
-		break;
-	    }
-	    else if (!retry) {
-		log_err ("accept: %m");
-		exit (1);
-	    }
-	}
-	
-	/*
-	 * Cree le processus de service (fils)
-	 */
-	if (!fork()) {
-#else
-	  /* Lecture du nom du client connecte */
-	  peer_name = get_peer_name ();
-#endif /* NO_NETWORK */
-
-#ifdef DEBUG_XTELD
-	    log_debug ("Connexion XTEL...");
-#endif
-
-	    /* Lecture du nom d'utilisateur */
-	    switch (type_client) {
-
-	    case CLIENT_W_HYPER:
-		if (lire_initial_hyper (utilisateur) < 0)
-		    goto fin_xteld;
-
-		appel_service (service);
-		break;
-
-	    case CLIENT_XTEL :
-		if (lire_chaine (utilisateur) < 0)
-		    goto fin_xteld;
-		
-		break;
-
-	    default :
-	      goto fin_xteld;
-		break;
-	    }
-
-	    /* lecture connexion XTEL */
-	    while (!fin_connexion) {
-		if (read (XTELD_INPUT, &c, 1) <= 0) {
-		    if (errno == EINTR)
-			continue;
-		    else
-			break;
-		}
-		if (flag_connexion) {
-		    if (c == VALEUR_COMMANDE_FIN) {
-#ifdef DEBUG_XTELD
-			log_debug ("tue le fils");
-#endif		      
-			kill (pid_fils, SIGTERM);
-		    }
-		    else {
-#ifdef NO_TERMIO
-			if (parite != SANS) {
-			    register int p;
-			    /* Calcul de parite... */			
-			    p = (c & 0x0f) ^ (c >> 4);
-			    p = (p & 3) ^ (p >> 2);      
-			    p = (p & 1) ^ (p >> 1);
-			    if (parite == IMPAIR)
-				p = ~p;
-			    c = (c & 0x7f) | (p << 7);
-			}
-#endif /* NO_TERMIO */
-			/*
-			 * on crit sur le modem que lorsque le code de service
-			 * a t entr o qu'il n'y en a pas.
-			 */
-			if (flag_serveur_local)
-			    write ( tuyau_out[1], &c, 1 );
-			else
-			    if (saisie_active)
-				write ( fd_modem, &c, 1);
-#ifdef DEBUG_XTELD
-			    else
-				log_debug( "saisie perdue : `%c' (%d)", c, c );
-#endif
-		    }
-		}
-		else {
-		    switch (c) {
-			
-		      case VALEUR_COMMANDE_CONNEXION_M1 :
-
-			appel_service (NULL);
-			break;
-
-		      case VALEUR_COMMANDE_DEMANDE_CONNEXION :
 			  
-			/* lecture du service */
-			if (lire_chaine(service) < 0)
-			    fin_connexion++;
-			else
-			    /* connexion */
-			    appel_service (service);
+	break;
 			  
-			break;
-			  
-		      case VALEUR_COMMANDE_SERVICE_SUIVANT :
+      case VALEUR_COMMANDE_NOM_UUCP :
 			    
-			if ((indice_service == nb_services) || flag_m1)
-			    write (XTELD_OUTPUT, CHAINE_REPONSE_PLUS_DE_SERVICE, 1);
-			else {
-			    if (service_autorise (indice_service, &temps_maxi)) {
-				c = strlen (definition_services[indice_service].nom_service);
-				write (XTELD_OUTPUT, &c, 1);
-				write (XTELD_OUTPUT, definition_services[indice_service].nom_service, c);
+	c = strlen (definition_services[indice_service].nom_uucp);
+	write (XTELD_OUTPUT, &c, 1);
+	write (XTELD_OUTPUT, definition_services[indice_service].nom_uucp, c);
 #ifdef DEBUG_XTELD
-				log_debug ("service: %s", definition_services[indice_service].nom_service);
+	log_debug ("%s", definition_services[indice_service].nom_uucp);
 #endif		      
-			    }
-			    else { /* service interdit */
-				c = 0;
-				write (XTELD_OUTPUT, &c, 1);
-				indice_service++;
-			    }
-			}
+	indice_service++;
 			  
-			break;
+	break;
 			  
-		      case VALEUR_COMMANDE_NOM_UUCP :
-			    
-			c = strlen (definition_services[indice_service].nom_uucp);
-			write (XTELD_OUTPUT, &c, 1);
-			write (XTELD_OUTPUT, definition_services[indice_service].nom_uucp, c);
-#ifdef DEBUG_XTELD
-			log_debug ("%s", definition_services[indice_service].nom_uucp);
-#endif		      
-			indice_service++;
-			  
-			break;
-			  
-		      default :
+      default :
 			      
-			break;
-		    }
-		}
-	    }
-
-fin_xteld:
-#ifdef NO_NETWORK
-
-	    /* Si xtel a ete tue sauvagement, tue le fils */
-	    test_mort_subite ();
-
-#ifdef DEBUG_XTELD
-	    log_debug ("Fin du service");
-#endif
-	    /* Fin du service */
-	    exit (0);
-
-	} /* if !fork */
-
-#ifdef DEBUG_XTELD
-	log_debug ("Ferme la socket de service");
-#endif
-	close (sock_service);
+	break;
+      }
     }
+  }
 
-#else
-
-#ifdef DEBUG_XTELD
-    log_debug ("%d meurt (OK), errno = %d", getpid(), errno);
-#endif
-
-    /* Si xtel a ete tue sauvagement, tue le fils */
-    test_mort_subite ();
-
-#endif /* NO_NETWORK */
-
-    close_debug ();
+ fin_xteld:
+  close_debug ();
 }
